<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Main Menu /////////////////////////
// Buttons:
define('MAIN_MENU_CONTENT_HEADING', "內容");

define('MAIN_MENU_EDIT_PAGE_BTN', "編輯內容");

define('MAIN_MENU_CREATE_PAGE_BTN', "創建頁");

define('MAIN_MENU_MANAGE_BORDER_AREAS_BTN', "管理邊境地區");

define('MAIN_MENU_MANAGE_IMAGES_BTN', "管理映像");

define('MAIN_MENU_PREVIEW_SITE_BTN', "預覽發布網站");

define('MAIN_MENU_EDIT_BLOG_BTN', "管理|編輯博客");

define('MAIN_MENU_EDIT_FILE_BTN', "編輯文件");

define('MAIN_MENU_MENUS_HEADING', "菜單");

define('MAIN_MENU_EDIT_MENUS_BTN', "編輯菜單");

define('MAIN_MENU_MANAGE_MENUS_BTN', "管理菜單分配");

define('MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN', "編輯CSS菜單參數");

define('MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN', "編輯CSS菜單樣式");

define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN', "編輯JS-菜單參數");

define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN_ALT', "編輯JavaScript的菜單參數");

define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN', "編輯JS-菜單樣式");

define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN_ALT', "編輯JavaScript的菜單樣式");

define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING', "樣式和head內容");

define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING_ALT', "樣式和head內容");

define('MAIN_MENU_EDIT_STYLES_BTN', "編輯樣式");

define('MAIN_MENU_EDIT_HEAD_BTN', "編輯開頭代碼");

define('MAIN_MENU_MANAGE_HEAD_BTN', "管理開頭代碼");

define('MAIN_MENU_EDIT_FAVICON_BTN', "編輯網站圖標");

define('MAIN_MENU_PAGE_MANAGEMENT_HEADING', "頁面管理");

define('MAIN_MENU_EDIT_PAGE_TITLES_BTN', "編輯頁面標題");

define('MAIN_MENU_EDIT_META_TAGS_BTN', "編輯Meta標籤");

define('MAIN_MENU_DELETE_PAGE_BTN', "刪除網頁或博客");

define('MAIN_MENU_COPY_RENAME_BTN', "複製或重命名頁面");

define('MAIN_MENU_RESTORE_BTN', "恢復頁面");

define('MAIN_MENU_ADD_PLUGIN_TO_PAGE_BTN', "安裝插件安裝到頁");

define('MAIN_MENU_MANAGE_PAGE_ACCESS_BTN', "管理頁面訪問");

define('MAIN_MENU_MANAGE_PAGE_ATTRIBUTES', "管理頁面屬性");

define('MAIN_MENU_SITE_MANAGEMENT_HEADING', "現場管理");

define('MAIN_MENU_RERUN_WIZARD_BTN', "重新運行嚮導");

define('MAIN_MENU_UPLOAD_TEMPLATE_BTN', "上傳模板");

define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN', "管理用戶和網站的選項");

define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT', "管理用戶和網站的選項");

define('MAIN_MENU_NEW_SESSION_BTN', "新的Session");

define('MAIN_MENU_LOGOUT_BTN', "登出");

// Console Text:

define('MAIN_MENU_HEADER_DIVIDER', "BREEZE網站建設MODULE");

// JavaScript Constants

define('MAIN_MENU_TIMEOUT_ERR', "您的會話已超時。你想重新登錄？");



///////////////////////// Login /////////////////////////

// Buttons:

define('LOGIN_LOGIN_BTN', "登錄");

// Console Text:

define('LOGIN_USERID_PASS_MSG', "請輸入您的用戶名和密碼");

define('LOGIN_SAVE_LOGIN_MSG', "保存日誌");

define('LOGIN_FORGOT_PASSWORD_MSG', "忘記密碼了嗎？");

define('LOGIN_JS_WARNING_MSG', "警告：必須啟用JavaScript使用這個系統。請在瀏覽器上打開javascipt的。");

define('LOGIN_ENTER_EMAIL_MSG', "請輸入您的電子郵件重置您的密碼");

define('LOGIN_CAPTCHA_MSG', "類型的名稱，或者您看到的字符<br />在上面的圖片中<span class='small_message'>（區分大小寫）</span>");

// Popup Messages:

define('LOGIN_CAPTCHA_ERR', "您的驗證碼輸入不正確。請再試一次。");

define('LOGIN_BAD_EMAIL_ERR', "您輸入的電子郵件地址無效。請再次鍵入您的電子郵件地址。");

define('LOGIN_BAD_REFERER_ERR', "你不出現是一個有效的。");

define('LOGIN_BAD_USER_ERR', "沒有用戶被發現的電子郵件。請重新輸入您的電子郵件地址。");

define('LOGIN_PASSWORD_RESET_ERR', "新密碼已發送到您的電子郵件。請檢查您的電子郵件消息。如果沒有找到消息，請檢查您spambox。");

define('LOGIN_DEFAULT_ERR', "一個奇怪的錯誤發生。請檢查太陽耀斑。");

define('LOGIN_SSL_WARNING_1', "注：為了您的瀏覽器保存的密碼，它需要發送未加密的這個時候。為了避免這個問題，請嘗試使用SSL加密連接（");

define('LOGIN_SSL_WARNING_2', "）。一定要告訴你的瀏覽器登錄後保存/更新您的密碼。");

define('LOGIN_EXCEEDED_MAX_ATTEMPTS', "您已經超出了登錄嘗試的最大數量。請與系統管理員聯繫。");

define('LOGIN_NO_USER_FOUND_ERR', "有該名稱的用戶。請重新恩特雷里奧斯您的用戶名和密碼。");

define('LOGIN_NO_USER_FOUND_1_ERR', "有該名稱的用戶。");

define('LOGIN_NO_USER_FOUND_2_ERR', "重新輸入您的用戶名和密碼。");

define('LOGIN_PASSWORD_NOT_CONFIRMED_MSG', "您的密碼還沒有得到證實。請重新輸入你的密碼。");

define('LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG', "您的密碼還沒有得到證實。");

define('LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG', "重新輸入您的密碼。");



///////////////////////// Version /////////////////////////

// Console Text:

define('VERSION_DB_PROGRAM_FILE_MISMATCH_MSG', "你的數據庫版本，補丁級別不匹配您的程序文件，修訂級別。請與系統管理員聯繫。");

define('VERSION_PROGRAM_FILES_VERSION_MSG', "程序文件修訂級別");

define('VERSION_DB_VERSION_MSG', "數據庫修補程序級別");



///////////////////////// Dashboard /////////////////////////

// Console Text:

define('WELCOME_1_MSG', "歡迎");

define('WELCOME_2_MSG', "微風網站製作™。點擊左邊的任何菜單標題來訪問系統工具建立自己的網站。");

define('WELCOME_INSTALL_FOLDER_PRESENT_1_WARNING', "<b>警告！</b>你的安裝文件夾仍然存在於服務器上。您的網站很容易受到影響。請點擊");

define('WELCOME_INSTALL_FOLDER_PRESENT_2_WARNING', "這裡");

define('WELCOME_INSTALL_FOLDER_PRESENT_3_WARNING', "從服務器中刪除<b><em>安裝</em></b>和<b><em>SQL</em></b>文件夾。");

define('WELCOME_LATEST_VERSION_INSTALLED_MSG', "微風網站製作™的最新版本安裝");

define('WELCOME_BETA_VERSION_INSTALLED_1_MSG', "您當前正在運行的測試版");

define('WELCOME_BETA_VERSION_INSTALLED_2_MSG', "微風網站製作™。目前的穩定版本是");

define('WELCOME_OLD_VERSION_INSTALLED_1_MSG', "版");

define('WELCOME_OLD_VERSION_INSTALLED_2_MSG', "微風網站生成器™的安裝。最新的版本是");

define('WELCOME_OLD_VERSION_INSTALLED_3_MSG', "點擊");

define('WELCOME_OLD_VERSION_INSTALLED_5_MSG', "下載所有的更高版本<br />升級比當前版本的文件。注意：您需要安裝這些更新順序，直到您的安裝是最新的。");

define('WELCOME_OLD_VERSION_INSTALLED_5A_MSG', "下載最新版本的升級文件。");

define('WELCOME_OLD_VERSION_INSTALLED_6_MSG', "下載更新後，點擊");

define('WELCOME_OLD_VERSION_INSTALLED_6A_MSG', "下載更新後，點擊");

define('WELCOME_OLD_VERSION_INSTALLED_7_MSG', "這裡");

define('WELCOME_OLD_VERSION_INSTALLED_8_MSG', "安裝下一個更新。");

define('WELCOME_OLD_VERSION_INSTALLED_8A_MSG', "進行安裝。");

define('WELCOME_OLD_VERSION_INSTALLED_9_MSG', "您需要先登錄，才能安裝更新的管理員。與系統管理員聯繫，以更新系統。");

define('WELCOME_UNKNOWN_VERSION_INSTALLED_1_MSG', "版");

define('WELCOME_UNKNOWN_VERSION_INSTALLED_2_MSG', "微風網站生成器™的安裝。 <span class='extra_small_message'><br />注：因為PHP指令<b><i>allow_url_fopen</i></b>已被關閉，我們不能與最新版本進行比較的版本。有此儀表板檢查您的版本，並為您提供鏈接的更新，則需要<b><i>allow_url_fopen選項</i></b>設置為<b><i>1，</i></b>在你的<b><i>php.ini</i></b>文件。</span>");

define('WELCOME_PAGE_COUNT', "頁數：");

define('WELCOME_BLOG_COUNT', "博客數：");

define('WELCOME_PLEASE_WAIT_DOWNLOADING_UPDATES_MSG', "請稍候。下載更新...這可能需要幾分鐘。");



///////////////////////// Edit Page Select /////////////////////////

// Buttons:

define('EDIT_PAGE_SELECT_HEADING', "編輯內容");

// Console Text:

define('EDIT_PAGE_SELECT_OPTIONS_HEADING', "編輯器選項");

define('EDIT_PAGE_SELECT_SOURCE_VIEW_OPTION', "在打開源視圖");

define('EDIT_PAGE_SELECT_MOBILE_STYLE_OPTION', "使用手機樣式");

define('EDIT_PAGE_SELECT_SITE_STYLES_HEADING', "網站風格");

define('EDIT_PAGE_SELECT_PAGE_DEFAULT_STYLES_OPTION', "使用默認頁");

define('EDIT_PAGE_SELECT_SITE_DEFAULT_STYLES_OPTION', "使用站點樣式");

define('EDIT_PAGE_SELECT_DISABLE_SITE_STYLES_OPTION', "禁用站點樣式");



/////////////// HTML/JavaScript/PHP/CSS Editor Pages /////////////////

// Buttons:

define('EDITOR_PREVIEW', "預習");

define('EDITOR_SAVE', "保存");

define('EDITOR_SAVE_AS', "另存為");

define('EDITOR_PUBLISH', "發布");

define('EDITOR_REVERT', "還原");

define('EDITOR_DELETE', "刪除");

define('EDITOR_SEE_SITE', "請參閱網站");

define('EDITOR_SEE_FILE', "請參閱文件");

define('EDITOR_CLEAR', "明確");

define('EDITOR_OPTIMIZE_IMAGES', "優化圖片");

define('EDITOR_RESET_IMAGES', "重置圖片");

define('EDITOR_EDIT_STYLES', "編輯樣式");

// Console Text:

define('EDITOR_PAGE_NAME', "頁面名稱");

define('EDITOR_FILE_NAME', "文件名");

define('EDITOR_HEAD_NAME', "頭名");

define('EDITOR_STYLE_SHEET', "樣式表");

// Popup Messages:

define('EDITOR_STARTING_UPDATE_MSG', "開始更新...");

define('EDITOR_PREPARING_PREVIEW_MSG', "正在準備預覽...");

define('EDITOR_REVERT_BLOG_CONFIRM_1_MSG', "在您確定要恢復<b>博客ID</b>");

define('EDITOR_REVERT_BLOG_CONFIRM_2_MSG', "？");

define('EDITOR_REVERT_AREA_CONFIRM_1_MSG', "你確定要恢復的");

define('EDITOR_REVERT_AREA_CONFIRM_2_MSG', "區？");

define('EDITOR_REVERT_PAGE_CONFIRM_1_MSG', "你確定要恢復的");

define('EDITOR_REVERT_PAGE_CONFIRM_2_MSG', "頁？");

define('EDITOR_REVERT_FILE_CONFIRM_1_MSG', "你確定要恢復的");

define('EDITOR_REVERT_FILE_CONFIRM_2_MSG', "文件？");

define('EDITOR_REVERT_HEAD_CONFIRM_1_MSG', "你確定要恢復的");

define('EDITOR_REVERT_HEAD_CONFIRM_2_MSG', "頭？");

define('EDITOR_REVERT_CSS_CONFIRM_1_MSG', "你確定要恢復的");

define('EDITOR_REVERT_CSS_CONFIRM_2_MSG', "CSS？");

define('EDITOR_REVERTING_MSG', "恢復到上次發布版本...");

define('EDITOR_REVERT_COMPLETE_MSG', "完成恢復");

define('EDITOR_PAGE_NOT_SAVED_MSG', "你的頁面不會被保存。你想保存更改？");

define('EDITOR_FILE_NOT_SAVED_MSG', "您的文件不會被保存。你想保存更改？");

define('EDITOR_HEAD_NOT_SAVED_MSG', "你的頭不會被保存。你想保存更改？");

define('EDITOR_CSS_NOT_SAVED_MSG', "你的CSS不會被保存。你想保存更改？");

define('EDITOR_PAGE_BLANK_ERR', "頁面名稱不能為空。請輸入頁面名稱，然後再試一次。");

define('EDITOR_FILE_BLANK_ERR', "文件名不能為空。請輸入一個文件名，然後再試一次。");

define('EDITOR_FOLDER_BLANK_ERR', "文件夾名稱不能為空。請輸入一個文件夾名稱，然後再試一次。");

define('EDITOR_HEAD_BLANK_ERR', "頭名不能為空。請輸入一個名稱的頭，然後再試一次。");

define('EDITOR_PAGE_ALREADY_EXISTS_1_ERR', "頁");

define('EDITOR_PAGE_ALREADY_EXISTS_2_ERR', "已經存在。請返回到主菜單複製和重命名頁面。");

define('EDITOR_AREA_ALREADY_EXISTS_1_ERR', "邊區");

define('EDITOR_AREA_ALREADY_EXISTS_2_ERR', "已經存在。請返回到主菜單管理邊境地區。");

define('EDITOR_FILE_ALREADY_EXISTS_1_ERR', "文件");

define('EDITOR_FILE_ALREADY_EXISTS_2_ERR', "已經存在。請返回到主菜單複製和重命名文件。");

define('EDITOR_FOLDER_ALREADY_EXISTS_1_ERR', "夾");

define('EDITOR_FOLDER_ALREADY_EXISTS_2_ERR', "已經存在。");

define('EDITOR_ERROR_CREATING_FOLDER_ERR', "錯誤：無法創建文件夾。");

define('EDITOR_HEAD_ALREADY_EXISTS_1_ERR', "頭");

define('EDITOR_HEAD_ALREADY_EXISTS_2_ERR', "已經存在。請返回到主菜單複製和重命名你的頭。");

define('EDITOR_DELETE_BLOG_CONFIRM_1_MSG', "你確定要刪除<b>博客ID</b>");

define('EDITOR_DELETE_BLOG_CONFIRM_2_MSG', "？");

define('EDITOR_DELETE_AREA_CONFIRM_1_MSG', "您確定要刪除");

define('EDITOR_DELETE_AREA_CONFIRM_2_MSG', "區？");

define('EDITOR_DELETE_PAGE_CONFIRM_1_MSG', "您確定要刪除");

define('EDITOR_DELETE_PAGE_CONFIRM_2_MSG', "頁？");

define('EDITOR_DELETE_FILE_CONFIRM_1_MSG', "您確定要刪除");

define('EDITOR_DELETE_FILE_CONFIRM_2_MSG', "文件？");

define('EDITOR_DELETE_HEAD_CONFIRM_1_MSG', "您確定要刪除");

define('EDITOR_DELETE_HEAD_CONFIRM_2_MSG', "頭？");





///////////////////////// Create Page Select /////////////////////////

// Buttons:

define('CREATE_PAGE_SELECT_HEADING', "創建頁");

define('CREATE_PAGE_SELECT_ENTER_PAGE_NAME_BTN', "輸入頁面的名稱");

define('CREATE_PAGE_SELECT_ADD_PLUGIN_BTN', "添加插件");

define('CREATE_PAGE_SELECT_SELECT_LAYOUT_BTN', "選擇佈局");

// Popup Messages:

define('CREATE_PAGE_SELECT_CREATING_A_PAGE', "創建一個頁面");

define('CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT', "選擇頁面佈局");

define('CREATE_PAGE_SELECT_HELPFUL_TIPS', "溫馨提示");



///////////////////////// Create Page Select /////////////////////////

// Console Text:

define('CREATE_PAGE_PAGE_NAME_BLANK_1_ERR', "哎呀！你忘了輸入頁面名稱。");

define('CREATE_PAGE_PAGE_NAME_BLANK_2_ERR', "並輸入頁面名稱。");

define('CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR', "進入不同的頁面名稱。");

define('CREATE_PAGE_DEFAULT_CONTENT', "在此輸入您的內容。");



///////////////////////// Manage Border Area Select /////////////////////////

// Buttons:

define('EDIT_BORDER_AREA_SELECT_HEADING', "編輯邊境地區");

define('MANAGE_BORDER_AREA_HEADING', "管理邊境地區");

define('MANAGE_BORDER_AREA_BTN', "管理自定義邊境地區");



///////////////////////// Manage Border Areas /////////////////////////

// Buttons:

define('MANAGE_CUSTOM_BORDER_AREA_HEADING', "管理自定義邊境地區");

// Console Text:

define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA', "添加邊區");

define('MANAGE_CUSTOM_BORDER_AREA_ASSIGN_AREA', "分配邊區頁");

define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA', "重命名邊區");

define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA', "刪除邊區");

define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA_SELECT', "選擇邊境地區重新命名");

define('MANAGE_CUSTOM_BORDER_AREA_NEW_NAME', "新名稱");

define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_SELECT', "選擇邊區刪除");

// Popup Messages:

define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_1_MSG', "您確定要刪除");

define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_2_MSG', "區？");

define('MANAGE_CUSTOM_BORDER_AREA_DELETED_1_MSG', "邊境地區");

define('MANAGE_CUSTOM_BORDER_AREA_DELETED_2_MSG', "已被刪除。");

define('MANAGE_CUSTOM_BORDER_AREA_DELETED_ERR', "錯誤：無法添加邊境地區");

define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_1_ERR', "不存在。");

define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_2_ERR', "返回到區域分配頁。");

define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_MSG', "邊境地區已重新分配到");

define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_MSG', "頁。");

define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_ERR', "錯誤：無法分配沿邊");

define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_ERR', "頁。");

define('MANAGE_CUSTOM_BORDER_AREA_NO_AREAS_FOUND_ERR', "錯誤：未找到邊境地區。");

define('MANAGE_CUSTOM_BORDER_AREA_ADDED_1_MSG', "邊境地區");

define('MANAGE_CUSTOM_BORDER_AREA_ADDED_2_MSG', "已被添加。");

define('MANAGE_CUSTOM_BORDER_AREA_ADDED_ERR', "錯誤：無法添加邊境地區");

define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_MSG', "已更名為");

define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_ERR', "錯誤：無法重命名");

define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR', "無法分配沿邊");

define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR', "頁面，因為它們已經被分配。");



///////////////////////// Edit Blog Select /////////////////////////

// Buttons:

define('EDIT_BLOG_SELECT_CREATE_HEADING', "創建頁面博客");

define('EDIT_BLOG_SELECT_EDIT_HEADING', "編輯帖子");



///////////////////////// Edit File Select /////////////////////////

// Buttons:

define('EDIT_FILE_SELECT_HEADING', "編輯文件");

define('EDIT_FILE_SELECT_PAGE_FILES_BTN', "編輯頁面文件");

define('EDIT_FILE_SELECT_INCLUDE_SCRIPTS_BTN', "包括編輯腳本");

define('EDIT_FILE_SELECT_LIB_MODULES_BTN', "編輯庫模塊");

// Console Text:

define('EDIT_FILE_SELECT_SELECT_FILE', "選擇文件");

// Popup Messages:

define('EDIT_FILE_SELECT_NO_FOLDER_ERR', "錯誤：沒有指定的文件夾");

///////////////////////// Edit Menu Items /////////////////////////
// Buttons:
define('EDIT_MENU_ITEMS_HEADING', "編輯菜單");
define('EDIT_MENU_ITEMS_UPDATE_ALL_BTN', "全部更新");
// Console Text:
define('EDIT_MENU_ITEMS_SELECT_MENU', "選擇一個菜單項添加到");
define('EDIT_MENU_ITEMS_ITEM_TEXT', "資料文本");
define('EDIT_MENU_ITEMS_NESTING_LEVEL', "嵌套級別");
define('EDIT_MENU_ITEMS_URL', "網址");
define('EDIT_MENU_ITEMS_TARGET_WINDOW', "目標窗口");
define('EDIT_MENU_ITEMS_TOP_LEVEL', "頂層");
define('EDIT_MENU_ITEMS_1ST_SUB_LEVEL', "1分級別");
define('EDIT_MENU_ITEMS_2ND_SUB_LEVEL', "第二子級");
define('EDIT_MENU_ITEMS_3RD_SUB_LEVEL', "3分等級");
define('EDIT_MENU_ITEMS_4TH_SUB_LEVEL', "4分等級");
define('EDIT_MENU_ITEMS_5TH_SUB_LEVEL', "5分級別");
define('EDIT_MENU_ITEMS_SELECT_MENU_MSG', "請選擇一個菜單，編輯菜單項。");
// Popup Messages:
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_1_MSG', "您確定要刪除");
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_2_MSG', "菜單項？");
define('EDIT_MENU_ITEMS_STARTING_DELETE_MSG', "開始刪除...");
define('EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG', "查找菜單項...");
define('EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG', "沒有找到記錄。無法刪除的菜單項。");
define('EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG', "菜單項刪除");
define('EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG', "刪除的菜單項...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG', "沒有找到記錄。無法更新菜單項。");
define('EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG', "菜單項更新");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG', "更新菜單項...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG', "沒有找到記錄。無法更新菜單項。");
define('EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG', "菜單項更新");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG', "更新菜單項...");
define('EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG', "檢索菜單項...");
define('EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG', "您的更改尚未保存。你想返回到主菜單前保存更改？");

///////////////////////// Manage Menu Assignments /////////////////////////
// Buttons:
define('MANAGE_MENUS_HEADING', "管理菜單分配");
define('MANAGE_MENUS_CREATE_NEW_MENU_BTN', "創建新菜單");
// Console Text:
define('MANAGE_MENUS_ADD_MENU', "添加菜單");
define('MANAGE_MENUS_MENU_TYPE', "菜單類型");
define('MANAGE_MENUS_ASSIGN_MENU_TO_BORDER', "指定菜單邊區");
define('MANAGE_MENUS_DELETE_MENU', "刪除菜單");
define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "選擇要刪除的菜單");
define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "更新菜單說明");
define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "選擇您要修改菜單");
define('MANAGE_MENUS_NEW_DESCRIPTION', "新的說明");
// Popup Messages:
define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "您需要將這個菜單重新分配到邊境地區完成轉換。");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "您確定要刪除");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_2_MSG', "菜單？");
define('MANAGE_MENUS_MENU_ASSIGNED_1_MSG', "該");
define('MANAGE_MENUS_MENU_ASSIGNED_2_MSG', "菜單");
define('MANAGE_MENUS_MENU_ASSIGNED_3_MSG', "已被分配給該");
define('MANAGE_MENUS_MENU_ASSIGNED_4_MSG', "邊區。");

///////////////////////// Edit CSS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_PARAMETERS_HEADING', "CSS菜單參數快速設置編輯器");
// Console Text:
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU', "選擇設置菜單");
define('EDIT_CSS_MENU_PARAMETERS_LAYOUT_ORIGIN', "菜單佈局和Origin（從頁面的左上角）");
define('EDIT_CSS_MENU_PARAMETERS_LOCATION', "菜單位置");
define('EDIT_CSS_MENU_PARAMETERS_FIXED_WIDTH', "（固定寬度）");
define('EDIT_CSS_MENU_PARAMETERS_VARIABLE_WIDTH', "（可變寬度）");
define('EDIT_CSS_MENU_PARAMETERS_MENU_WIDTH', "菜單的寬度");
define('EDIT_CSS_MENU_PARAMETERS_SPECIAL_NOTE', "注：選擇上述任何位置不分配菜單，這些領域之一。它只是強調了這種形式與所選區域的典型設置。");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SIZE_PADDING', "菜單項大小和填充");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_POSITIONING', "子菜單定位");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_TOP', "從頂部偏移");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_LEFT', "從左偏移");
define('EDIT_CSS_MENU_PARAMETERS_COLLAPSE_EXPAND', "折疊和展開");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_SIZE_PADDING', "子菜單項目大小和填充");
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU_MSG', "請選擇設置菜單。");

///////////////////////// Edit CSS Menu Styles /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_STYLES_HEADING', "CSS菜單樣式快速設置編輯器");
// Console Text:
define('EDIT_CSS_MENU_STYLES_SELECT_MENU', "選擇菜單樣式");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_FONT', "頂級字體");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_FONT', "分1級字體");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_FONT', "分2級字體");
define('EDIT_CSS_MENU_STYLES_COLORS_BACKGROUND', "顏色和背景");
define('EDIT_CSS_MENU_STYLES_NORMAL_MOUSE_OUT', "正常（鼠標移出）");
define('EDIT_CSS_MENU_STYLES_HOVER_MOUSE_OVER', "哈弗（鼠標懸停）");
define('EDIT_CSS_MENU_STYLES_ACTIVE_MOUSE_CLICK', "活動（鼠標點擊）");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_TEXT_COLOR', "頂級文本顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_TEXT_COLOR', "分1級文字顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "分2級文本顏色");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "頂級背景顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "分等級背景顏色");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "最頂層的方塊邊框顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "子級別1塊邊框顏色");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "頂層項目邊框顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "分層次的項目邊框顏色");
define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "ŧ <br> Ø <br> p");
define('EDIT_CSS_MENU_STYLES_BOTTOM_BORDER_VERTICAL', "乙<br> Ø <br> ŧ <br> ŧ <br> Ø <br>米");
define('EDIT_CSS_MENU_STYLES_LEFT_BORDER_VERTICAL', "大號<br> Ë <br> F <br> ŧ");
define('EDIT_CSS_MENU_STYLES_RIGHT_BORDER_VERTICAL', "-  [R <br>一世<br> G <br> H <br> ŧ");
define('EDIT_CSS_MENU_STYLES_UNDERLINE_NOTE', "鏈路下劃線將被迫關閉，除非下劃線被檢查");
define('EDIT_CSS_MENU_STYLES_SAME_AS_TOP_LEVEL_NOTE', "（同頂層）");
define('EDIT_CSS_MENU_STYLES_SAME_AS_NORMAL_NOTE', "（同正常）");
define('EDIT_CSS_MENU_STYLES_SELECT_MENU_MSG', "請選擇一個風格的菜單。");
// Popup Messages:
define('EDIT_CSS_MENU_STYLES_LETTER_SPACING_MSG', "您選擇<b>正常</b> ， <b>初步</b>或<b>繼承</b>你的來信間距，但你有字母間距數設置。請注意，您選擇的電話號碼將被忽略。如果你想設置一個字母間距，選擇<b>像素</b>來代替。");
define('EDIT_CSS_MENU_STYLES_SAVE_SUCCESS_MSG', "你的菜單樣式已保存。");
define('EDIT_CSS_MENU_STYLES_SAVE_FAIL_ERR', "有一個錯誤保存您的菜單樣式。");

///////////////////////// Edit JS Menu Parameters /////////////////////////

// Buttons:

define('EDIT_JS_MENU_PARAMETERS_HEADING', "JavaScript的菜單大小和方向編輯");

// Console Text:

define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU', "選擇設置菜單");

define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_SIZE', "菜單項大小");

define('EDIT_JS_MENU_PARAMETERS_MENU_ORIGIN', "菜單原點（從頁面的左上角）");

define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ORIGIN', "子菜單產地（從主菜單的左上角）");

define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_OFFSET', "菜單項偏移");

define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ITEM_OFFSET_SIZE', "子菜單項目偏置和尺寸");

define('EDIT_JS_MENU_PARAMETERS_PROPORTIONAL_SIZING', "施膠比例");

define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_WIDTH', "子菜單項目寬度");

define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_HEIGHT', "子菜單項目高度");

define('EDIT_JS_MENU_PARAMETERS_OFFSET_FROM_LEFT_OF_TOP_MENU', "從主菜單的左偏移");

define('EDIT_JS_MENU_PARAMETERS_HIDE_DELAY_ON_MOUSE_OUT', "鼠標移出後隱藏延遲（毫秒）");

define('EDIT_JS_MENU_PARAMETERS_VERTICAL_HORIZONTAL_MENU_NOTE', "注：偏移由左到0。由上到0偏移橫向菜單設置垂直菜單集。");

define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU_MSG', "請選擇設置菜單。");

// Popup Messages:

define('EDIT_JS_MENU_PARAMETERS_SAVE_SUCCESS_MSG', "你的菜單參數已經保存。");

define('EDIT_JS_MENU_PARAMETERS_SAVE_FAIL_ERR', "有一個錯誤保存您的菜單參數。");



///////////////////////// Edit JS Menu Styles /////////////////////////

// Buttons:

define('EDIT_JS_MENU_STYLES_HEADING', "JavaScript的菜單樣式編輯器");

// Console Text:

define('EDIT_JS_MENU_STYLES_SELECT_MENU', "選擇菜單樣式");

define('EDIT_JS_MENU_STYLES_TOP_MENU_MENU', "頂級菜單");

define('EDIT_JS_MENU_STYLES_SUB_LEVEL_1_MENU', "子一級菜單");

define('EDIT_JS_MENU_STYLES_SUB_LEVEL_2_MENU', "分2級菜單");

define('EDIT_JS_MENU_STYLES_PADDING', "填充（右上左下）");

define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "請選擇一個風格的菜單。");



///////////////////////// Edit CSS Select /////////////////////////

// Buttons:

define('EDIT_CSS_SELECT_HEADING', "編輯樣式");

define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "在桌面/手機/觸摸屏之間複製樣式表");

define('COPY_STYLE_TO_MOBILE_NOTE', "此功能用於在桌面，手機或觸摸屏視圖中的任意一個完成設置樣式表後，使用類似的桌面，移動或觸摸屏樣式來初始化桌面，移動或觸摸屏樣式。使用此功能將覆蓋您為要復製到的目標桌面，移動設備或觸摸屏樣式表創建的任何樣式。沒有必要使用這個功能，但它可以作為創建您的移動樣式後的樣式桌面網站或反之亦然的起點。此外，您可以為默認情況下沒有類似移動樣式表的樣式表創建移動或觸摸屏樣式表。");

define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "你確定要複製");

define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "？所有的樣式");

define('COPY_STYLE_TO_MOBILE_CONFIRM_3_MSG', "將被覆蓋。 （這不能被撤消。）");

define('COPY_STYLE_TO_MOBILE_COMPLETE_MSG', "已複製到");

define('COPY_STYLE_TO_MOBILE_COMPLETE_ERR', "有一個錯誤的複製");

// Popup Messages:

define('EDIT_CSS_SELECT_MENU_WARNING', "警告：編輯菜單CSS直接會導致不可預測的結果。菜單樣式應使用菜單樣式編輯器來完成。在CSS編輯器編輯CSS菜單只能由專業Web開發人員來完成。");

define('EDIT_CSS_SELECT_MENU_ITEM_WARNING', "注意：當造型各個菜單項，“顯示”設置為“列表項”來激活它們的網絡瀏覽器。");



///////////////////////// Edit CSS /////////////////////////

// Buttons:

define('EDIT_CSS_HEADING', "編輯樣式");

define('EDIT_CSS_ADD_DELETE_CUSTOM_STYLE_BTN', "添加/刪除自定義樣式");

define('EDIT_CSS_LOAD_BROWSER_RESET_CSS_BTN', "瀏覽器加載CSS重置");

define('EDIT_CSS_SETUP_CENTERED_PAGES_BTN', "設置居中的頁面");

define('EDIT_CSS_SETUP_STICKY_FOOTER_BTN', "設置粘性頁腳");

// Console Text:

define('EDIT_CSS_CHANGE_STYLE_SHEET', "更改樣式表");

define('EDIT_CSS_USE_SETTINGS_BELOW', "使用下面的設置");

define('EDIT_CSS_GO_TO', "去");

define('EDIT_CSS_SORT_ALPHABETICALLY', "按字母順序排序");

define('EDIT_CSS_CLICK_NONE_MSG', "點擊“無”才明確執行不文飾。");

define('EDIT_CSS_WHITE_SPACE', "空白");

define('EDIT_CSS_TABLE_LAYOUT', "表佈局");

define('EDIT_CSS_CURSOR', "光標");

define('EDIT_CSS_OUTLINE_STYLE', "外形風格");

define('EDIT_CSS_BORDER_COLLAPSE', "邊境崩潰");

define('EDIT_CSS_TOP_LEFT', "左上角");

define('EDIT_CSS_TOP_RIGHT', "右上");

define('EDIT_CSS_BOTTOM_RIGHT', "右下角");

define('EDIT_CSS_BOTTOM_LEFT', "左下方");

define('EDIT_CSS_Z_INDEX', "Z指數");

define('EDIT_CSS_BACKGROUND_IMAGE', "背景圖");

define('EDIT_CSS_CLICK_AUTO_MSG', "點擊“自動”只明確地執行自動保證金。");

define('EDIT_CSS_REPEAT_HORIZONTALLY', "水平重複");

define('EDIT_CSS_REPEAT_VERTICALLY', "垂直重複");

define('EDIT_CSS_NO_REPEAT', "無重複");

define('EDIT_CSS_INLINE_BLOCK', "inline-block的");

define('EDIT_CSS_LIST_ITEM', "列表項");

define('EDIT_CSS_RUN_IN', "跑進");

define('EDIT_CSS_INLINE_TABLE', "內嵌表");

define('EDIT_CSS_TABLE_ROW_GROUP', "表行集團");

define('EDIT_CSS_TABLE_FOOTER_GROUP', "表尾集團");

define('EDIT_CSS_TABLE_ROW', "表行集團");

define('EDIT_CSS_TABLE_COLUMN_GROUP', "表列組");

define('EDIT_CSS_TABLE_COLUMN', "表列組");

define('EDIT_CSS_TABLE_CELL', "表格單元格");

define('EDIT_CSS_TABLE_CAPTION', "表格標題");

define('EDIT_CSS_ALL_SCROLL', "所有滾動");

define('EDIT_CSS_CONTEXT_MENU', "上下文菜單");

define('EDIT_CSS_COLUMN_RESIZE', "調整大小列");

define('EDIT_CSS_ROW_RESIZE', "行調整大小");

define('EDIT_CSS_NO_DROP', "沒有下降");

define('EDIT_CSS_NOT_ALLOWED', "不允許");

define('EDIT_CSS_VERTICAL_TEXT', "垂直文本");

define('EDIT_CSS_EAST_RESIZE', "調整窗口");

define('EDIT_CSS_EAST_WEST_RESIZE', "東西方調整大小");

define('EDIT_CSS_NORTH_RESIZE', "北調整大小");

define('EDIT_CSS_NORTH_EAST_RESIZE', "東北調整大小");

define('EDIT_CSS_NORTH_EAST_SOUTH_WEST_RESIZE', "東北 - 西南調整大小");

define('EDIT_CSS_NORTH_SOUTH_RESIZE', "南北調整大小");

define('EDIT_CSS_NORTH_WEST_RESIZE', "西北調整大小");

define('EDIT_CSS_NORTH_WEST_SOUTH_EAST_RESIZE', "北西 - 南東調整大小");

define('EDIT_CSS_SOUTH_RESIZE', "南調整大小");

define('EDIT_CSS_SOUTH_EAST_RESIZE', "東南調整大小");

define('EDIT_CSS_SOUTH_WEST_RESIZE', "西南調整大小");

define('EDIT_CSS_WEST_RESIZE', "西調整大小");

define('EDIT_CSS_ZOOM_IN', "放大");

define('EDIT_CSS_ZOOM_OUT', "縮小");

define('EDIT_CSS_TOP_CENTER', "頂部中心");

define('EDIT_CSS_CENTER_LEFT', "中心左");

define('EDIT_CSS_CENTER_CENTER', "中心中心");

define('EDIT_CSS_CENTER_RIGHT', "右中心");

define('EDIT_CSS_BOTTOM_CENTER', "底部中心");

define('EDIT_CSS_XPOS_YPOS', "XPOS Ypos");

define('EDIT_CSS_DECIMAL_LEADING_ZERO', "十進制前導零");

define('EDIT_CSS_LOWER_ROMAN', "羅馬較低");

define('EDIT_CSS_UPPER_ROMAN', "大寫羅馬");

define('EDIT_CSS_LOWER_ALPHA', "阿爾法較低");

define('EDIT_CSS_UPPER_ALPHA', "阿爾法上限");

define('EDIT_CSS_LOWER_GREEK', "希臘較低");

define('EDIT_CSS_LOWER_LATIN', "拉丁較低");

define('EDIT_CSS_UPPER_LATIN', "上拉丁語");

define('EDIT_CSS_CJK_IDEOGRAPHIC', "CJK-表意文字");

define('EDIT_CSS_HIRAGANA', "平假名");

define('EDIT_CSS_KATAKANA', "片假名");

define('EDIT_CSS_HIRAGANA_IROHA', "平假名伊呂波");

define('EDIT_CSS_KATAKANA_IROHA', "片假名伊呂波");

// Popup Messages:

define('EDIT_CSS_CLICK_UPDATE_TO_COMMIT_MSG', "點擊“更新”提交更改。");

define('EDIT_CSS_UPDATE_COMPLETE_MSG', "更新完成");

define('EDIT_CSS_UPDATE_READY_TO_SEND_MSG', "更新準備送...");

define('EDIT_CSS_UPDATE_SENT_MSG', "發送更新");

define('EDIT_CSS_UPDATING_MSG', "更新中...");

define('EDIT_CSS_RESET_BROWSER_CSS_COMPLETE_MSG', "你的CSS已設置的所有的邊緣，填充和邊界的HTML元素設置為0以重置的瀏覽器，並且所有的邊緣的主體元素為0的。");

define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_ALERT_MSG', "現在，我們將與設置，將導致您的網站出現了固定寬度居中加載風格。");

define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_COMPLETE_MSG', "您的網站已居中。您可能要修改“身體”的寬度，“body”的背景色，而“#wrap”backgound顏色您的需求。");

define('EDIT_CSS_LOAD_STICKY_FOOTERS_ALERT_MSG', "現在，我們將與設置，將導致您的網頁頁腳“大棒”到瀏​​覽器窗口的底部加載風格。");

define('EDIT_CSS_LOAD_STICKY_FOOTERS_COMPLETE_MSG', "您的頁腳現在會堅持到瀏覽器窗口的底部。您可能還需要修改“頁腳”的高度和背景顏色您的需求。請務必頁腳的保證金最高設置為相同的，但負面的頁腳的高度。");

define('EDIT_CSS_BORDER_REQUIREMENTS_MSG', "看來，你正試圖建立一個邊框，但是選擇任何雙方你沒有。你必須檢查標籤<b>上</b> ， <b>下</b> ， <b>左</b>或<b>右</b>的箱子中的至少一個。");

define('EDIT_CSS_BORDER_REQUIREMENTS_STYLE_ADENDUM_MSG', "你必須為了使邊框顯示指定<b>邊框樣式</b> 。");

define('EDIT_CSS_LETTER_SPACING_REQUIREMENTS_MSG', "您選擇<b>正常</b> ， <b>初步</b>或<b>繼承</b>你的來信間距，但你有字母間距數設置。請注意，您選擇的電話號碼將被忽略。如果你想設置一個字母間距，選擇<b>像素</b>來代替。");

define('EDIT_CSS_LINE_HEIGHT_REQUIREMENTS_MSG', "您選擇<b>普通</b>或<b>繼承</b>你的行高，但你有行高正數設置。請注意，您選擇的電話號碼將被忽略。如果你想設置的行高，選擇<b>Bultiplyer，</b>或<b>％，</b>而不是<b>像素</b> 。");

define('EDIT_CSS_SORTING_CLASS_LIST_MSG', "排序類列表...");

define('EDIT_CSS_SORT_COMPLETE', "排序完成");

define('EDIT_CSS_SORTING_MSG', "排序...");

define('EDIT_CSS_COULD_NOT_RENAME_1_ERR', "無法重命名");

define('EDIT_CSS_COULD_NOT_RENAME_2_ERR', "至");

define('EDIT_CSS_CANT_CREATE_ERR', "無法創建");

define('EDIT_CSS_SELECT_PAGE_FOR_PREVIEW', "選擇一個頁面以預覽CSS的變化");



///////////////////////// Edit CLASSES /////////////////////////

// Buttons:

define('CLASSES_HEADING', "添加/刪除自定義樣式");

define('CLASSES_BACK_TO_EDIT_CSS', "返回編輯網站的CSS");

// Console Text:

define('CLASSES_ADD_CLASS', "添加類");

define('CLASSES_CREATE_SUB_CLASS', "創建類/子類的關係");

define('CLASSES_DELETE_CLASS', "刪除班級");

define('CLASSES_EDIT_CLASS_DESCRIPTION', "編輯類說明");

define('CLASSES_SET_CLASS_SORT_ORDER', "組類排序");

define('CLASSES_CREATE_LINK_SET', "創建鏈接集");

define('CLASSES_CLASS_DESCRIPTION', "類/說明");

define('CLASSES_CLASS_ID_NOTE', "選擇“類”的。 （點）的前綴或選擇&#39;ID&#39;為＃前綴。");

define('CLASSES_COPY_CLASS', "複製/重命名類");

define('CLASSES_FROM_CLASS', "從階級");

define('CLASSES_TO_CLASS', "上課");

define('CLASSES_TO_STYLE_SHEET', "為了樣式表");

define('CLASSES_NO_CUSTOM_CLASSES_DEFINED', "- 沒有自定義類denfined-");

// Popup Messages:

define('CLASSES_DELETE_CLASS_CONFIRM_1_MSG', "你確定要刪除的類");

define('CLASSES_DELETE_CLASS_CONFIRM_2_MSG', "？");

define('CLASSES_DESCRIPTION_NOT_FOUND_MSG', "沒有找到記錄。找不到說明。");

define('CLASSES_DESCRIPTION_FOUND_MSG', "說明找到");

define('CLASSES_COULD_NOT_UPDATE_DESCRIPTION_MSG', "沒有找到記錄。無法更新說明。");

define('CLASSES_DESCRIPTION_UPDATED_MSG', "更新說明");

define('CLASSES_STARTING_POPULATE_MSG', "開始填充...");

define('CLASSES_COPY_FROM_CLASS_BLANK_ERR', "請選擇一個類從複製。");

define('CLASSES_COPY_TO_CLASS_BLANK_ERR', "請輸入一個類來複製。");

define('CLASSES_COPY_CLASS_COMPLETE_MSG', "類複製完成！");

define('CLASSES_COPY_CLASS_ERR', "發生錯誤試圖複製類。");

define('CLASSES_COPY_CLASS_TO_CLASS_ALREADY_EXISTS_ERR', "錯誤：您要複製到類已經存在。");

define('CLASSES_UPDATE_SORT_ORDER_COMPLETE_MSG', "排序訂單已經更新。");

define('CLASSES_UPDATE_SORT_ORDER_UPDATE_ERR', "錯誤：有一個錯誤更新排序順序。");

define('CLASSES_ADD_CLASS_COMPLETE_MSG', "你的新類已添加。");

define('CLASSES_ADD_CLASS_ADD_ERR', "已經存在於數據庫中。");

define('CLASSES_DEFINE_SUBCLASS_COMPLETE_MSG', "你的新的子類已創建。");

define('CLASSES_DEFINE_SUBCLASS_DEFINE_ERR', "錯誤：有一個錯誤創建新的子類。");

define('CLASSES_DELETE_CLASS_COMPLETE_MSG', "類成功刪除。");

define('CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG', "類/ ID名稱不能為空。請類或ID名稱填寫。");



///////////////////////// Edit Head Select /////////////////////////

// Buttons:

define('EDIT_HEAD_SELECT_HEADING', "編輯開頭代碼");



///////////////////////// Manage Head /////////////////////////

// Buttons:

define('MANAGE_HEAD_HEADING', "管理開頭代碼");

define('MANAGE_HEAD_ADD_HEAD_BTN', "添加另一個頭內容");

// Console Text:

define('MANAGE_HEAD_ADD_HEAD_CONTENT', "添加頭內容");

define('MANAGE_HEAD_ASSIGN_HEAD_CONTENT_TO_PAGE', "分配頭內容頁");

define('MANAGE_HEAD_RENAME_HEAD_CONTENT', "重命名文件頭內容");

define('MANAGE_HEAD_DELETE_HEAD_CONTENT', "刪除頭內容");

define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_RENAME', "選擇頭的內容重新命名");

define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_DELETE', "選擇頭內容刪除");

define('MANAGE_HEAD_NEW_NAME', "新名稱");

// Popup Messages:

define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_1_MSG', "您確定要刪除");

define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_2_MSG', "頭？");

define('MANAGE_HEAD_DELETED_1_MSG', "頭部");

define('MANAGE_HEAD_DELETED_2_MSG', "已被刪除。");

define('MANAGE_HEAD_DELETED_ERR', "錯誤：無法添加頭");

define('MANAGE_HEAD_NO_HEADS_FOUND_ERR', "錯誤：未找到負責人。");

define('MANAGE_HEAD_NOT_FOUND_1_ERR', "不存在。");

define('MANAGE_HEAD_NOT_FOUND_2_ERR', "返回到頭部分配的頁面。");

define('MANAGE_HEAD_ASSIGNED_1_MSG', "已被重新分配到");

define('MANAGE_HEAD_ASSIGNED_2_MSG', "頁。");

define('MANAGE_HEAD_ASSIGNED_1_ERR', "錯誤：無法分配");

define('MANAGE_HEAD_ASSIGNED_2_ERR', "到");

define('MANAGE_HEAD_ASSIGNED_3_ERR', "頁。");

define('MANAGE_HEAD_ADDED_1_MSG', "頭部");

define('MANAGE_HEAD_ADDED_2_MSG', "已被添加。");

define('MANAGE_HEAD_ADDED_ERR', "錯誤：無法添加頭");

define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_1_ERR', "頭部");

define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR', "已經存在。請輸入一個不同的頭名。");

define('MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR', "無法分配");

define('MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR', "頁面，因為它已被分配。");



///////////////////////// Edit Favicon /////////////////////////

// Buttons:

define('EDIT_FAVICON_HEADING', "編輯網站圖標");

define('EDIT_FAVICON_UPLOAD_BTN', "上傳");

// Console Text:

define('EDIT_FAVICON_UPLOAD_FAVICON', "上傳網站圖標");

// Popup Messages:

define('EDIT_FAVICON_DELETE_FAVICON_CONFIRM', "你確定要刪除的圖標？");

define('EDIT_FAVICON_UPLOAD_SUCCESS_MSG', "圖標已上傳。");

define('EDIT_FAVICON_ONLY_ICONS_ALLOWED_MSG', "只有圖標文件允許上傳，即“myicon.ico”。請點擊");

define('EDIT_FAVICON_UPLOAD_FAIL_ERR', "有一個錯誤上傳文件。");



///////////////////////// Edit Page Titles /////////////////////////

// Buttons:

define('EDIT_PAGE_TITLES_HEADING', "編輯頁面標題");

// Console Text:

define('EDIT_PAGE_TITLES_REVISE_DEFAULT_PAGE_TITLE', "修改默認的頁面標題");

define('EDIT_PAGE_TITLES_SELECT_PAGE', "選擇一個頁面更改標題");

define('EDIT_PAGE_TITLES_REVISE_SITE_TITLE', "修改網站標題");

define('EDIT_PAGE_TITLES_SITE_TITLE_NOTE', "如果存在附加到頁面標題");

// Popup Messages:

define('EDIT_PAGE_TITLES_PAGE_TILE_SAVED_MSG', "頁面標題已保存。");



///////////////////////// Edit Meta Tags /////////////////////////

// Buttons:

define('EDIT_META_TAGS_HEADING', "編輯Meta標籤");

// Console Text:

define('EDIT_META_TAGS_SELECT_PAGE', "選擇頁面");

define('EDIT_META_TAGS_KEYWORDS_NOTE', "注意：使用逗號“，”分隔的關鍵詞和關鍵短語。");

// Popup Messages:

define('EDIT_META_TAGS_META_TAGS_SAVED_MSG', "Meta標籤已保存。");



///////////////////////// Delete Page or Blog /////////////////////////

// Buttons:

define('DELETE_PAGE_OR_BLOG_HEADING', "刪除網頁或博客");

// Console Text:

define('DELETE_PAGE_OR_BLOG_SELECT_PAGE', "選擇要刪除的頁面");

define('DELETE_PAGE_OR_BLOG_SELECT_BLOG', "選擇您要刪除的博客文章");

// Popup Messages:

define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG', "是你確定要刪除");

define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG', "？");

define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG', "是你確定要刪除");

define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG', "頁？");

define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG', "是你確定要召回");

define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG', "插入？");



///////////////////////// Copy/Raname Select Page /////////////////////////

// Buttons:

define('COPY_RENAME_PAGE_HEADING', "複製或重命名頁面");

define('COPY_RENAME_PAGE_COPY_RENAME_BTN', "複製/重命名");

// Console Text:

define('COPY_RENAME_PAGE_DISCARD_TEMPLATE_NOTE', "廢舊頁面模板，並創造新");

define('COPY_RENAME_PAGE_RENAME_PAGE_LINK_NOTE', "注意：重命名頁面不會改變您所創建的任何鏈接。菜單項目都將自動更新，但您將需要更改存在任何頁面引用新的頁面名稱的任何鏈接。");



///////////////////////// Copy/Raname Page /////////////////////////

// Buttons:

define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_BTN', "覆蓋目標");

define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_RETAIN_TEMPLATE_BTN', "覆蓋目標的內容，但保留目的地模板");

define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_CREATE_NEW_TEMPLATE_BTN', "與源內容覆蓋目的地創建每個選定的站點選擇新模板");

define('COPY_RENAME_PAGE_CANCEL_COPY_BTN', "取消一份，將複製/重命名控制台");

// Console Text:

define('COPY_RENAME_PAGE_PAGE_ALREADY_EXISTS', "已經存在。您想做什麼？");

// Popup Messages:

define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_1_MSG', "哎呀！你忘了選擇一個頁面進行重命名。");

define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_2_MSG', "並選擇一個頁面重新命名。");

define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_1_MSG', "哎呀！你忘了輸入一個新的頁面名稱。");

define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_2_MSG', "並進入一個新的頁面名稱。");

define('COPY_RENAME_PAGE_COPY_ONTO_SELF_1_MSG', "你無法將一個頁面複製到自身。 （除非你有選擇拋棄舊的模板並創建一個新的。）");

define('COPY_RENAME_PAGE_COPY_ONTO_SELF_2_MSG', "並進入一個新的頁面名稱。");

define('COPY_RENAME_PAGE_ERROR_OPENING_NEW_PAGE_ERR', "錯誤打開新的頁面文件。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_ERROR_UPDATING_PAGE_NAME_REFERENCES_ERR', "在新的頁面文件更新時出錯頁面的名稱引用。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_AFETR_REFERENCE_UPDATE_ERR', "在新的頁面文件中的錯誤頁面收盤名稱引用。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE', "返回到複製/重命名控制台。");

define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_1_ERR', "這一頁");

define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_2_ERR', "已經存在。不能重命名");

define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_3_ERR', "並輸入一個不同的目的地名稱。");

define('COPY_RENAME_PAGE_UNKNOWN_ERROR_ERR', "一些如何，我們不能確定，如果你想複製或重命名。請返回從列表中選擇一個操作。");

define('COPY_RENAME_PAGE_RENAME_OLD_PAGE_NOT_FOUND_ERR', "未找到。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_ERROR_RENAMING_PAGE_ERR', "錯誤重命名文件。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_ERROR_OPENING_ORIGINAL_PAGE_ERR', "錯誤打開原來的頁面文件。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_ERROR_WRITING_TO_NEW_PAGE_ERR', "寫入錯誤內容，新的頁面文件。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_ERR', "錯誤關閉新的頁面文件。請與系統管理員聯繫。");

define('COPY_RENAME_PAGE_CANT_READ_ERR', "無法讀取");



///////////////////////// Restore Page /////////////////////////

// Buttons:

define('RESTORE_PAGE_HEADING', "恢復頁面");

define('RESTORE_PAGE_SHOW_CONTENT_BTN', "展示內容");

define('RESTORE_PAGE_SHOW_CODE_BTN', "顯示代碼");

// Console Text:

define('RESTORE_PAGE_SELECT_PAGE', "選擇要恢復的頁面");

define('RESTORE_PAGE_DELETE_FROM_HISTORY', "從歷史記錄刪除");

// Popup Messages:

define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_1_MSG', "您確定要<b>刪除</b>");

define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_2_MSG', "從備份歷史記錄頁面？");

define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_1_MSG', "您確定要<b>恢復</b>");

define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_2_MSG', "頁？");



///////////////////////// Add Plugin to Page /////////////////////////

// Buttons:

define('ADD_PLUGIN_TO_PAGE_HEADING', "安裝插件安裝到頁");

define('ADD_PLUGIN_TO_PAGE_SELECT_PAGE_HEADING', "選擇頁面");

define('ADD_PLUGIN_TO_PAGE_SELECT_PLUGIN_HEADING', "選擇插件");

// Console Text:

define('ADD_PLUGIN_TO_PAGE_PAGE_SELECTED', "頁面選擇");

define('ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED', "插件選擇");

// Popup Messages:

define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_1_MSG', "該");

define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_2_MSG', "插件被插入到");

define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_3_MSG', "頁。");

define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_1_MSG', "哎呀！你忘了選擇一個頁面和/或插件。");

define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_2_MSG', "並選擇頁面和插件。");

define('ADD_PLUGIN_TO_PAGE_ERROR_OPENING_PAGE_FILE_ERR', "錯誤打開頁面文件。請與系統管理員聯繫。");

define('ADD_PLUGIN_TO_PAGE_ERROR_UPDATING_PAGE_FILE_ERR', "更新時出錯頁面文件。請與系統管理員聯繫。");

define('ADD_PLUGIN_TO_PAGE_ERROR_CLOSING_PAGE_FILE_ERR', "收盤時出錯頁面文件。請與系統管理員聯繫。");

define('ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG', "返回到嵌件插件 - 進入 - 頁面控制台。");

define('ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG', "無法重命名");



///////////////////////// Mange Page Access /////////////////////////

// Buttons:

define('MANAGE_PAGE_ACCESS_HEADING', "管理受限網頁和網站用戶");

define('MANAGE_PAGE_ACCESS_ADD_LOGIN_FIELDS_BTN', "添加用戶登錄<br />字段表");

define('MANAGE_PAGE_ACCESS_ASSIGN_WELCOME_MESSAGE_PAGE_BTN', "分配歡迎辭<br />頁面，用戶表");

// Console Text:

define('MANAGE_PAGE_ACCESS_RESTRICT_PAGE_ACCESS', "限制頁訪問");

define('MANAGE_PAGE_ACCESS_APPROVE_ACCESSTO_USERS', "批准用戶訪問");

define('MANAGE_PAGE_ACCESS_USER_TABLE_SETUP', "用戶表設置");

define('MANAGE_PAGE_ACCESS_SHOW_LOGIN_LINKS_ALWAYS', "顯示登入<br />始終鏈接");

define('MANAGE_PAGE_ACCESS_REQUIRE_LOGIN', "需要登錄");

define('MANAGE_PAGE_ACCESS_LOGIN_PAGE', "登錄頁面");

define('MANAGE_PAGE_ACCESS_MESSAGE_PAGE', "信息頁");

define('MANAGE_PAGE_ACCESS_FIRST_LAST', "（第一，最後）");

define('MANAGE_PAGE_ACCESS_OPTIONAL', "（可選的）");

define('MANAGE_PAGE_ACCESS_ADDITIONAL_FORMS_NOTE', "用戶通過該網站創建的窗體（S）通常被添加。下面的形式都包括允許另外通過微風網站製作後台的用戶由網站管理員和高級用戶。");

// Popup Messages:

define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_1_MSG', "你確定要刪除的用戶");

define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_2_MSG', "？");

define('MANAGE_PAGE_ACCESS_USER_DELETED_1_MSG', "用戶");

define('MANAGE_PAGE_ACCESS_USER_DELETED_2_MSG', "已被刪除");

define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_1_MSG', "你確定要刪除的訪問級別");

define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_2_MSG', "？");

define('MANAGE_PAGE_ACCESS_LOCATING_PAGE_RESTRICTIONS_MSG', "查找頁面限制...");

define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_PAGE_RESTRICTIONS_MSG', "沒有找到記錄。無法更新頁面的限制。");

define('MANAGE_PAGE_ACCESS_PAGE_RESTRICTIONS_UPDATED_MSG', "頁面限制更新");

define('MANAGE_PAGE_ACCESS_UPDATING_PAGE_RESTRICTIONS_MSG', "更新頁面的限制...");

define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_USER_STATUS_MSG', "沒有找到記錄。無法更新用戶狀態。");

define('MANAGE_PAGE_ACCESS_USER_STATUS_UPDATED_MSG', "用戶狀態更新");

define('MANAGE_PAGE_ACCESS_UPDATING_USER_STATUS_MSG', "更新用戶狀態...");

define('MANAGE_PAGE_ACCESS_COULD_NOT_MODIFY_TABLE_MSG', "無法修改表");

define('MANAGE_PAGE_ACCESS_FIELDS_ADDED_TO_TABLE_MSG', "字段添加到表");

define('MANAGE_PAGE_ACCESS_ADDING_FIELDS_TO_TABLE_MSG', "將字段添加到表...");

define('MANAGE_PAGE_ACCESS_WELCOME_MESSAGE_PAGE_ADDED_TO_TABLE_MSG', "歡迎信息頁面添加到表");

define('MANAGE_PAGE_ACCESS_ADDING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "添加歡迎消息頁面表...");

define('MANAGE_PAGE_ACCESS_COULD_NOT_ADD_DELETE_ACCESS_LEVEL_MSG', "無法添加或刪除訪問級別。");

define('MANAGE_PAGE_ACCESS_ACESS_LEVEL_RECORDS_MODIFIED_MSG', "訪問級別記錄修改");

define('MANAGE_PAGE_ACCESS_CHANGING_ACCESS_LEVELS_MSG', "更改訪問級別...");

define('MANAGE_PAGE_ACCESS_LOCATING_ACCESS_LEVELS_MSG', "查找訪問級別...");

define('MANAGE_PAGE_ACCESS_LOCATING_USERS_MSG', "查找用戶...");

define('MANAGE_PAGE_ACCESS_REQUIRED_FIELDS_MSG', "請確保您正在使用的用戶的形式與名稱“電子郵件”，“用戶名”和“密碼”字段。如果你選擇的表是使用帳戶創建表單插件創建，那麼這些領域已經在此表中。");

define('MANAGE_PAGE_ACCESS_RETRIEVING_PAGE_RESTRICTIONS_MSG', "檢索頁面的限制...");

define('MANAGE_PAGE_ACCESS_RETRIEVING_ACCESS_LEVELS_MSG', "檢索訪問級別...");

define('MANAGE_PAGE_ACCESS_RETRIEVING_USERS_MSG', "檢索用戶...");

define('MANAGE_PAGE_ACCESS_ADDING_LOGIN_FIELDS_TO_TABLE_MSG', "添加登錄字段的表...");

define('MANAGE_PAGE_ACCESS_ASSIGNING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "歡迎分配消息頁表...");

define('MANAGE_PAGE_ACCESS_ADDING_ACCESS_LEVEL_MSG', "添加訪問級別...");

define('MANAGE_PAGE_ACCESS_REMOVING_ACCESS_LEVEL_MSG', "刪除訪問級別...");

define('MANAGE_PAGE_ACCESS_NEW_USER_NOT_ADDED_ERR', "發生錯誤。不添加新的用戶。");

define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_1_MSG', "新用戶");

define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_2_MSG', "一直與密碼創建");

define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_3_MSG', "和的訪問級別");

define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_4_MSG', "對於");

define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_5_MSG', "與電子郵件");

define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_1_MSG', "對於用戶的密碼");

define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_2_MSG', "已變更");

define('MANAGE_PAGE_ACCESS_USER_CHANGED_1_MSG', "用戶");

define('MANAGE_PAGE_ACCESS_USER_CHANGED_2_MSG', "已被修改為訪問級別");

define('MANAGE_PAGE_ACCESS_USER_CHANGED_3_MSG', "，一個名稱");

define('MANAGE_PAGE_ACCESS_USER_CHANGED_4_MSG', "和的電子郵件");

define('MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR', "錯誤：未找到該用戶數據");

define('MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR', "你必須有一個用戶表中選擇，如果你想需要登錄才能訪問的頁面。請選擇一個用戶表，然後再試一次。");

define('MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR', "你必須選擇一個登錄頁面，如果你想需要登錄才能訪問的頁面。請選擇一個登錄頁面，然後再試一次。如果在列表中沒有登錄頁面，則必須先創建一個登錄頁面至極登錄插件。登錄頁面的名稱必須包含“登錄”。");





///////////////////////// Manage Page Attributes /////////////////////////

// Buttons:

define('MANAGE_PAGE_ATTRIBUTES_HEADING', "管理頁面屬性");

define('MANAGE_PAGE_ATTRIBUTES_TEMPLATE_HEADING', "佈局模板");

// Console Text:

define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES', "頁面屬性");

define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES', "使用頁表結構");

define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES_FOR_MOBILE', "使用頁表結構的移動");

define('MANAGE_PAGE_ATTRIBUTES_CALL_BODY_ONLOAD_FUNCTION', "呼叫身體的OnLoad功能");

define('MANAGE_PAGE_ATTRIBUTES_DISABLE_SITE_STYLES_WHEN_EDITING', "禁用網站的風格，當編輯");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEAD', "插入默認頭到自定義頭");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEADER', "將默認標題為自定義頁眉");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_TOP', "插入默認頂進自定義首頁");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_LEFT', "將默認的左到自定義左");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_RIGHT', "將默認權限到自定義權限");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_BOTTOM', "插入默認底部插入自定義底部");

define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_FOOTER', "插入默認頁腳到自定義頁腳");

// Popup Messages:

define('MANAGE_PAGE_ATTRIBUTES_ERROR_RETRIEVING_PAGE_ATTRIBUTES_ERR', "有一個錯誤檢索頁面屬性。");

define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES_SAVED_MSG', "頁面屬性已保存。");

define('MANAGE_PAGE_ATTRIBUTES_ERROR_SAVING_PAGE_ATTRIBUTES_ERR', "有一個錯誤保存頁面屬性。");

define('MANAGE_PAGE_ATTRIBUTES_ERROR_ONLOAD_ERR', "如果“呼叫身體的OnLoad功能”被選中，該功能不能為空。");



///////////////////////// Upload Template /////////////////////////

// Buttons:

define('UPLOAD_TEMPLATE_HEADING', "上傳模板");

// Console Text:

define('UPLOAD_TEMPLATE_CONFIRM_MSG', "是你確定要上傳新的模板？繼續將取代當前的站點和變化是不可逆的。你會得到你是否希望保留網頁內容的選擇，但主題和邊境地區的內容將被替換。");

define('RERUN_WIZARD_RUN_WIZARD_CONFIRM_MSG', "是你確定要重新運行該嚮導？繼續將取代當前的站點和變化是不可逆的。你會得到你是否希望保留網頁內容的選擇，但主題和邊境地區的內容將被替換。");

define('UPLOAD_TEMPLATE_BUILDING_SITE_MSG', "建築工地模板....");

define('UPLOAD_TEMPLATE_WHEN_COMPLETE_SCROLL_TO_BOTTOM_MSG', "完成後，滾動到下繼續。");

define('UPLOAD_TEMPLATE_ALLOWED_FILE_TYPE_MSG', "只有gzip壓縮的tar文件都可以被上載，即“template_105.tgz&#39;或&#39;template_26.tar.gz”。請點擊");

define('UPLOAD_TEMPLATE_COPYING_USER_FILES_MSG', "複製用戶文件...");

define('UPLOAD_TEMPLATE_COPYING_PAGES_MSG', "複印頁數...");

define('UPLOAD_TEMPLATE_COPYING_IMAGES_MSG', "複製圖片...");

define('UPLOAD_TEMPLATE_COPYING_CSS_MSG', "複製CSS ...");

define('UPLOAD_TEMPLATE_COPYING_MEDIA_MSG', "將媒體...");

define('UPLOAD_TEMPLATE_COPYING_FLASH_MSG', "複製閃...");

define('UPLOAD_TEMPLATE_COPYING_SCRIPTS_MSG', "複製腳本...");

define('UPLOAD_TEMPLATE_COPYING_XML_MSG', "複製XML ...");

define('UPLOAD_TEMPLATE_UNABLE_TO_OPEN_DOC_ROOT_ERR', "無法打開文檔根目錄。");

define('UPLOAD_TEMPLATE_COULD_NOT_RENAME_ERR', "無法重命名");

define('UPLOAD_TEMPLATE_CANT_CREATE_ERR', "無法創建");

define('UPLOAD_TEMPLATE_ERROR_UPLOADING_FILE_ERR', "有一個錯誤上傳文件。");

define('UPLOAD_TEMPLATE_TO_CONTINUE_MSG', "接著說。");

define('UPLOAD_TEMPLATE_SQL_FILE_MSG', "SQL文件...");

define('UPLOAD_TEMPLATE_SQL_FILE_NAME_NOT_DEFINED_ERR', "致命錯誤：SQL文件名沒有定義。");

define('UPLOAD_TEMPLATE_SQL_MSG', "SQL ...");

define('UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG', "行（多個）的影響。");

define('UPLOAD_TEMPLATE_SELECT_TEMPLATE_FROM_YOUR_COMPUTER', "選擇您想從您的計算機安裝的模板：");

define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES', "刪除所有頁面");

// Popup Messages:

define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG', "你確定要刪除所有頁面內容？");

define('UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG', "上傳模板，請稍候...");

define('UPLOAD_TEMPLATE_UPLOADING', "上傳模板，請稍候...");



///////////////////////// Admin Function Select /////////////////////////

// Buttons:

define('ADMIN_FUNCTION_SELECT_HEADING', "管理用戶和網站的選項");

define('ADMIN_FUNCTION_SELECT_MANAGE_USERS_BTN', "管理用戶");

define('ADMIN_FUNCTION_SELECT_CHANGE_SITE_OPTIONS_BTN', "更改站點選項");

define('ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN', "限制頁面編輯訪問");

define('ADMIN_FUNCTION_SELECT_GENERATE_SITE_MAP_BTN', "生成網站地圖");

define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_BTN', "西梅頁編輯備份表");

define('ADMIN_FUNCTION_SELECT_PRUNE_BACKUP_FILES_BTN', "西梅CSS，網站地圖， <br />文件編輯備份， <br /> JavaScript的菜單備份文件");

define('ADMIN_FUNCTION_SELECT_CLEAR_CUSTOM_CLASSES_BTN', "清除全部自定義CSS類");

define('ADMIN_FUNCTION_SELECT_INSTALL_PLUGIN_BTN', "安裝插件");

define('ADMIN_FUNCTION_SELECT_RECALL_PLUGIN_BTN', "召回插件");

define('ADMIN_FUNCTION_SELECT_INSTALL_UPDATE_BTN', "安裝更新");

define('ADMIN_FUNCTION_SELECT_RUN_SQL_BTN', "SQL運行");

define('ADMIN_FUNCTION_SELECT_SHOW_SERVER_INFO_BTN', "顯示服務器信息");

define('ADMIN_FUNCTION_SELECT_DEACTIVATE_WEBSITE_BTN', "取消激活網站");

define('ADMIN_FUNCTION_SELECT_ACTIVATE_WEBSITE_BTN', "激活網站");

// Console Text:

define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_TO', "西梅頁編輯備份表");

define('ADMIN_FUNCTION_SELECT_SELECT_PLUGIN_TO_RECALL', "選擇您要調用插件");

// Popup Messages:

define('ADMIN_FUNCTION_SELECT_DEACTIVATE_SITE_CONFIRM_MSG', "你想利用你的網站下線？");

define('ADMIN_FUNCTION_SELECT_ACTIVATE_SITE_CONFIRM_MSG', "你想利用你的網站住在哪裡？");

define('ADMIN_FUNCTION_SELECT_BACKUP_FILES_HAVE_BEEN_PRUNED_MSG', "CSS，網站地圖，和JavaScript菜單備份文件已被刪節。");



///////////////////////// Manage Users /////////////////////////

// Buttons:

define('MANAGE_USERS_HEADING', "管理用戶");

// Console Text:

define('MANAGE_USERS_SSL_NOT_PRESENT_WARNING', "<b>警告：</b>您正在使用未加密的連接查看此控制台。如果要添加用戶或更改密碼，建議您使用加密連接。要切換到加密連接，單擊");

define('MANAGE_USERS_INVALID_CERTIFICATE_NOTE', "注意：SSL證書可能無效。如果是這種情況，就接受證書無論如何，繼續加密連接。此外，一些服務器沒有安裝SSL證書，所以它可能無法查看此控制台加密。如果點擊鏈接不起作用只需單擊後退按鈕。");

// Popup Messages:

define('MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG', "是你確定要刪除的用戶");

define('MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG', "？");

define('MANAGE_USERS_USER_DELETED_1_MSG', "用戶");

define('MANAGE_USERS_USER_DELETED_2_MSG', "已被刪除");

define('MANAGE_USERS_NO_USERS_FOUND_ERR', "錯誤：未找到用戶");

define('MANAGE_USERS_NO_DATA_FOUND_FOR_USER_ERR', "錯誤：未找到該用戶數據");

define('MANAGE_USERS_USER_NOT_ADDED_ERR', "發生錯誤。不添加新的用戶。");

define('MANAGE_USERS_NEW_USER_ADDED_1_MSG', "新用戶");

define('MANAGE_USERS_NEW_USER_ADDED_2_MSG', "一直與密碼創建");

define('MANAGE_USERS_NEW_USER_ADDED_3_MSG', "和的訪問級別");

define('MANAGE_USERS_NEW_USER_ADDED_4_MSG', "對於");

define('MANAGE_USERS_NEW_USER_ADDED_5_MSG', "與電子郵件");

define('MANAGE_USERS_PASSWORD_CHANGED_1_MSG', "對於用戶的密碼");

define('MANAGE_USERS_PASSWORD_CHANGED_2_MSG', "已變更");

define('MANAGE_USERS_USER_MODIFIED_1_MSG', "用戶");

define('MANAGE_USERS_USER_MODIFIED_2_MSG', "已被修改為訪問級別");

define('MANAGE_USERS_USER_MODIFIED_3_MSG', "，一個名稱");

define('MANAGE_USERS_USER_MODIFIED_4_MSG', "和的電子郵件");

define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_1_ERR', "您必須先選擇一個表將用戶添加到。");

define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR', "選擇一個表，然後再試一次。");

define('MANAGE_USERS_USER_ALREADY_EXISTS_ERR', "進入不同的用戶名。");

define('MANAGE_USERS_NO_TABLE_TO_CHANGE_USER_PASSWORD_ERR', "您必須先選擇一個表來更改用戶的密碼。");

define('MANAGE_USERS_NO_TABLE_TO_DELETE_USER_FROM_ERR', "您必須先選擇一個表來刪除一個用戶。");



///////////////////////// Manage SIte Options /////////////////////////

// Buttons:

define('MANAGE_SITE_OPTIONS_HEADING', "更改站點選項");

// Console Text:

// Popup Messages:

define('MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG', "該選項已被保存。");

define('MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR', "有一個錯誤保存選項。");



///////////////////////// Restrict Page Editing Access /////////////////////////

// Buttons:

define('RESTRICT_PAGE_EDITING_HEADING', "為限制限制用戶訪問編輯頁");

// Console Text:

// Popup Messages:

define('RESTRICT_PAGE_EDITING_RESTRICTIONS_SAVED_MSG', "頁面限制已保存。");



///////////////////////// Generate Site Map /////////////////////////

// Buttons:

define('GENERATE_SITE_MAP_HEADING', "生成網站地圖");

// Console Text:

define('GENERATE_SITE_MAP_GENERATING', "生成網站地圖...");

define('GENERATE_SITE_MAP_COULD_NOT_RENAME_1_ERR', "無法重命名");

define('GENERATE_SITE_MAP_COULD_NOT_RENAME_2_ERR', "至");

define('GENERATE_SITE_MAP_ERROR_CREATING_SITEMAP_ERR', "錯誤creatng站點地圖。");

define('GENERATE_SITE_MAP_SITEMAP_REBUILD_COMPLETE', "網站地圖重建完成！");

define('GENERATE_SITE_MAP_SITEMAP_CREATION_COMPLETE', "網站地圖製作完成！");

define('GENERATE_SITE_MAP_ROBOT_FILE_CREATED', "機器人文件創建！");

define('GENERATE_SITE_MAP_CANT_CREATE_ERR', "無法創建");



///////////////////////// Install Plugin /////////////////////////

// Buttons:

define('INSTALL_PLUGIN_HEADING', "安裝插件");

// Console Text:

define('INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN', "請輸入您的用戶帳戶的密碼");

define('INSTALL_PLUGIN_SELECT_PLUGIN_FROM_YOUR_COMPUTER', "選擇插件，你想從你的計算機上安裝");

define('INSTALL_PLUGIN_INSTALLING_PLUGIN', "安裝插件....");

define('INSTALL_PLUGIN_WRONG_FILE_TYPE_MSG', "只有壓縮文件或gzip壓縮的tar文件都可以被上載，即“plugin.zip&#39;或&#39;plugin.tgz&#39;或&#39;plugin.tar.gz”。請點擊");

define('INSTALL_PLUGIN_EXTRACTING_FILES', "解壓縮文件...");

define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1_ERR', "有一個錯誤從壓縮文件解壓縮文件。");

define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1A_ERR', "有一個錯誤從tar.gz文件解壓縮文件。");

define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1B_ERR', "有一個錯誤從tar文件解壓縮文件。");

define('INSTALL_PLUGIN_COPYING_FILES', "複製文件...");

define('INSTALL_PLUGIN_PLUGIN_INSTALLATION_COMPLETE', "插件安裝comlplete。");

define('INSTALL_PLUGIN_ADD_NEW_BUTTON_TO_MENU_MSG', "添加新的插件按鈕菜單。");

define('INSTALL_PLUGIN_ERROR_UPLOADING_FILE_ERR', "有一個錯誤上傳文件。");

// Popup Messages:



///////////////////////// Install Update /////////////////////////

// Buttons:

define('INSTALL_UPDATE_HEADING', "安裝更新");

// Console Text:

define('INSTALL_UPDATE_SELECT_UPDATE_FROM_YOUR_COMPUTER', "選擇更新您想從您的計算機安裝");

define('INSTALL_UPDATE_INSTALLING_UPDATE', "安裝更新....");

define('INSTALL_UPDATE_WRONG_FILE_TYPE_MSG', "只有gzip壓縮的tar文件或壓縮文件都可以被上載，即“breeze_update_x.x.xx.tgz&#39;或&#39;breeze_update_x.x.xx.tar.gz&#39;或&#39;breeze_update_x.x.xx.zip”。請點擊");

define('INSTALL_UPDATE_UPDATE_INSTALLATION_COMPLETE', "更新安裝完成。");

define('INSTALL_UPDATE_REFRESH_MAIN_MENU', "刷新主菜單。");

// Popup Messages:

define('INSTALL_UPDATE_NEW_VERSION_AVAILABLE', "有可用的微風網站製作的新版本。你想立即更新嗎？ <br /><p class='medium_message' style='text-align:left;'>此消息將顯示每次你打開微風，直到它被更新。如果你的微風版本將成為多個版本過時，您將停止接收這些信息，你將需要半手動執行增量更新。 </p>");

define('INSTALL_UPDATE_VERSION_ERROR_ERR', "試圖執行自動更新，但有以前的版本，版本文件版本和數據庫版本之間的不匹配。");



///////////////////////// Run SQL /////////////////////////

// Buttons:

define('RUN_SQL_HEADING', "SQL運行");

// Console Text:

define('RUN_SQL_PASTE_SQL_MSG', "粘貼或輸入SQL語句（S）到窗口上方。然後點擊“提交”。");

define('RUN_SQL_SQL_COMMAND_DELIMITERS_NOTE', "注意：每個SQL命令必須用分號（;）結束。行開頭（ - ）或（//）將被視為註釋。");



///////////////////////// Javascript Menu Params and Styles /////////////////////////

// Popup Messages:

define('JS_MENU_PARAM_NO_PACAMETERS_1_ERR', "無參數已設置完畢。");

define('JS_MENU_PARAM_NO_PACAMETERS_2_ERR', "回去填入參數。");

define('JS_MENU_STYLES_ERROR_SAVING_RECORD_ERR', "出錯試圖保存記錄");

define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_1_MSG', "是你確定要刪除該JavaScript的菜單代碼");

define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_2_MSG', "？");



///////////////////////// Options /////////////////////////

// Strings:

define('OPTIONS_TEMPLATE', "模板");

define('OPTIONS_FORCE_PAGE_NAME_TO_LOWER_CASE', "強制頁面名稱為小寫");

define('OPTIONS_ENABLE_WIZARD', "啟用嚮導");

define('OPTIONS_RUN_WIZARD_LOCAL', "運行嚮導本地（檢查只有當模板庫和微風安裝是同一台服務器上）。");

define('OPTIONS_ENABLE_FILE_MANAGER_FOR_RESTRICTED_USERS', "啟用受限用戶文件管理器");

define('OPTIONS_ACTIVATE_NEW_USERS_AUTOMATICALLY', "激活新用戶自動");

define('OPTIONS_USE_TABLE_STRUCTURES', "使用表結構");

define('OPTIONS_USE_TABLE_STRUCTURES_ON_MOBILE', "在移動使用表結構");

define('OPTIONS_CREATE_ACCOUNT_LINK_TEXT', "創建帳戶鏈接文本");

define('OPTIONS_LOGIN_LINK_TEXT', "登錄鏈接文本");

define('OPTIONS_MY_ACCOUNT_LINK_TEXT', "我的帳戶鏈接文本");

define('OPTIONS_LOGOUT_LINK_TEXT', "註銷鏈接文本");

define('OPTIONS_CREATE_ACCOUNT_LINK', "創建帳戶鏈接文本");

define('OPTIONS_LOGIN_LINK', "登錄鏈接文本");

define('OPTIONS_MY_ACCOUNT_LINK', "我的帳戶鏈接文本");

define('OPTIONS_LOGOUT_REDIRECT_OVERRIDE', "註銷重定向覆蓋");

define('OPTIONS_EDITOR_SOURCE_VIEW_THEME', "編輯源視圖主題");

define('OPTIONS_BREEZE_WEBSITE_BUILDER_THEME', "微風網站製作主題");

define('OPTIONS_LOCKOUT_CLEAR_ALL_CUSTOM_CSS_CLASSES', "鎖定清除全部自定義CSS類");

define('OPTIONS_LOCKOUT_COPY_STYLE_SHEET_TO_MOBILE', "鎖定複製樣式表到手機");



////////////////////// Manage Custom Fonts /////////////////////////////////////

// Buttons:

define('MANAGE_CUSTOM_FONTS_HEADING', "管理自定義字體");

// Console Text:

define('MANAGE_CUSTOM_FONTS_ADD_FONT', "添加字體");

define('MANAGE_CUSTOM_FONTS_DELETE_FONT', "刪除字體");

define('MANAGE_CUSTOM_FONTS_NO_FONTS', "- 無定制fonts-");

define('MANAGE_CUSTOM_FONTS_STRETCH', "伸展");

define('MANAGE_CUSTOM_FONTS_STYLE', "樣式");

define('MANAGE_CUSTOM_FONTS_WEIGHT', "重量");

// Popup Messages:

define('MANAGE_CUSTOM_FONTS_GET_FONTS_MSG', "獲取字體...");

define('MANAGE_CUSTOM_FONTS_GET_FONTS_COMPLETE_MSG', "字體填充完整。");

define('MANAGE_CUSTOM_FONTS_ADDING_FONT_MSG', "添加字體...");

define('MANAGE_CUSTOM_FONTS_ADDING_FONT_COMPLETE_MSG', "添加字體完整。");

define('MANAGE_CUSTOM_FONTS_ADDING_FONT_1_ERR', "字體與源");

define('MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR', "已經存在。");

define('MANAGE_CUSTOM_FONTS_ADDING_FONT_UPLOAD_ERR', "對不起，有錯誤上傳您的字體。");

define('MANAGE_CUSTOM_FONTS_ADDING_FONT_FILE_TYPE_ERR', "對不起，只有TTF，OTF，WOFF，WOFF2，SVG和EOT文件是允許的。");

define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_1_MSG', "您確定要刪除");

define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_2_MSG', "字體與源");

define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_3_MSG', "？");

define('MANAGE_CUSTOM_FONTS_DELETE_FONT_COMPLETE_MSG', "字體刪除。");



////////////////////// Clear All Custom CSS Classes /////////////////////////////////////

// Buttons:

define('CLEAR_CUSTOM_CSS_CLASSES_HEADING', "清除自定義CSS類");

// Console Text:

define('CLEAR_CUSTOM_CSS_CLASSES_ALL_STYLE_SHEETS', "所有樣式表");

// Popup Messages:

define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_MSG', "警告：此操作過程使用會深刻地影響你的網站。這種變化不能被撤銷。你確定要繼續嗎？");

define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_2_MSG', "警告：此操作的目的是在CH375復位您的網站，或特定的插件或菜單到出廠默認設置，以幫助。 <br />這種變化不能被撤銷。這是最後一次警告你。你想繼續嗎？");

define('CLEAR_CUSTOM_CSS_CLASSES_START_MSG', "清除自定義CSS類...");

define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_MSG', "清除自定義CSS類完成。");

define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_ERR', "有一個錯誤清除自定義CSS類。");



////////////////////// Backup/Restore /////////////////////////////////////

// Buttons:

define('BACKUP_RESTORE_HEADING', "備份和還原站點");

// Console Text:

define('BACKUP_RESTORE_SELECT_BACKUP', "選擇要還原的備份");

define('BACKUP_RESTORE_SELECT_BACKUP_TO_UPLOAD', "選擇備份要從計算機才能恢復");

define('BACKUP_RESTORE_DELETE_BACKUP', "刪除備份");

define('BACKUP_RESTORE_RETAIN_MEDIA', "合併與當前還原圖像和媒體");

define('BACKUP_RESTORE_UPLOAD_LARGE_BKUPS_MSG', "超過300兆字節更大的上傳備份文件可能會失敗。如果發生這種情況，FTP備份文件到public_html下的“備份”文件夾，並刷新此控制台。");

// Popup Messages:

define('BACKUP_RESTORE_CREATING_BACKUP_PLEASE_WAIT_MSG', "備份網站，請稍候...");

define('BACKUP_RESTORE_UPLOADING_BACKUP_PLEASE_WAIT_MSG', "上傳備份，請稍候...");

define('BACKUP_RESTORE_RESTORING_WEBSITE', "恢復網站....滾動到底何時完成。");

define('BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG', "你確定你想要從恢復");

define('BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG', "備份文件？");

define('BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG', "您確定要刪除");

define('BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG', "備份文件已被刪除。");

define('BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR', "有一個錯誤刪除備份文件。");

define('BACKUP_RESTORE_ERROR_CREATING_FOLDER_ERR', "無法創建");

define('BACKUP_RESTORE_ERROR_ERROR_WRITING_FILE_ERR', "不能寫入文件");

define('BACKUP_RESTORE_BACKUP_COMPLETE_MSG', "備份完成！");

define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_1_MSG', "您的備份可供下載。");

define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_2_MSG', "下載您的備份。");

define('BACKUP_RESTORE_RETURN_TO_MSG', "要返回備份/恢復控制台");

define('BACKUP_RESTORE_WRONG_FILE_TYPE_1_MSG', "只有壓縮文件或gzip壓縮的tar文件都可以被上載，即“backup_54121247.zip&#39;或&#39;backup_54121247.tgz&#39;或&#39;backup_54121247.tar.gz”。請點擊");

define('BACKUP_RESTORE_RESTORE_COMPLETE', "現場恢復完成。");

define('BACKUP_RESTORE_DUMPING_DATABASE', "轉儲數據庫...");

define('BACKUP_RESTORE_ZIPPING_FILES', "歸檔文件...");







///////////////// Standard words and phrases ///////////////////////

define('WELCOME_WORD', "歡迎");

define('ACCESS_LEVEL_WORD', "訪問級別");

define('YES_WORD', "是");

define('NO_WORD', "沒有");

define('SUBMIT_WORD', "提交");

define('OK_WORD', "好");

define('CANCEL_WORD', "取消");

define('VERSION_WORD', "版");

define('USERID_WORD', "用戶名");

define('USERNAME_WORD', "用戶名");

define('PASSWORD_WORD', "密碼");

define('EMAIL_WORD', "電子郵件");

define('NAME_WORD', "用戶名");

define('DASHBOARD_WORD', "儀表板");

define('SAVE_AS_WORD', "另存為");

define('CREATE_WORD', "創建");

define('UPDATE_WORD', "更新");

define('REQUIRED_WORD', "需要");

define('OPTIONAL_WORD', "可選的");

define('PLUGINS_WORD', "插件");

define('RIGHT_WORD', "對");

define('LEFT_WORD', "剩下");

define('TOP_WORD', "最佳");

define('BOTTOM_WORD', "底部");

define('HEADER_WORD', "頭");

define('FOOTER_WORD', "頁腳");

define('HEAD_WORD', "頭");

define('ERROR_WORD', "錯誤");

define('ERROR_CAPS_WORD', "錯誤");

define('HERE_WORD', "這裡");

define('NEW_WORD', "新");

define('DESCRIPTION_WORD', "描述");

define('DATE_WORD', "更新");

define('LINK_WORD', "鏈接");

define('TARGET_WORD', "目標");

define('ACTIVE_WORD', "活性");

define('USER_TABLE_WORD', "用戶表");

define('HEADER_1ST_CAP_WORD', "頭");

define('TOP_1ST_CAP_WORD', "最佳");

define('LEFT_1ST_CAP_WORD', "剩下");

define('RIGHT_1ST_CAP_WORD', "對");

define('BOTTOM_1ST_CAP_WORD', "底部");

define('FOOTER_1ST_CAP_WORD', "頁腳");

define('HEAD_1ST_CAP_WORD', "頭");

define('VERTICAL_WORD', "垂直");

define('HORIZONTAL_WORD', "橫");

define('OFFSET_WORD', "抵消");

define('POSITION_WORD', "位置");

define('POSITIONING_WORD', "定位");

define('ABSOLUTE_WORD', "絕對");

define('RELATIVE_WORD', "相對的");

define('WIDTH_WORD', "寬度");

define('HEIGHT_WORD', "高度");

define('PROPORTIONAL_WORD', "成比例的");

define('PADDING_WORD', "填充");

define('ORIENTATION_WORD', "方向");

define('CENTER_WORD', "中央");

define('JUSTIFY_WORD', "辯解");

define('FONT_WORD', "字形");

define('SIZE_WORD', "尺寸");

define('WEIGHT_WORD', "重量");

define('ITALIC_WORD', "斜體");

define('UNDERLINE_WORD', "強調");

define('OVERLINE_WORD', "上劃線");

define('LINETHROUGH_WORD', "刪除線");

define('BLINK_WORD', "眨");

define('OBLIQUE_WORD', "斜");

define('SHADOW_WORD', "陰影");

define('COLOR_WORD', "顏色");

define('X_OFFSET_WORD', "的X偏移");

define('Y_OFFSET_WORD', "Y型膠印機");

define('BLUR_WORD', "模糊");

define('OPACITY_WORD', "不透明度");

define('WEBSAFE_WORD', "網絡安全");

define('NA_WORD', "吶");

define('NORMAL_WORD', "正常");

define('BOLD_WORD', "膽大");

define('BOLDER_WORD', "更大膽");

define('LIGHTER_WORD', "打火機");

define('INITIAL_WORD', "初始");

define('INHERIT_WORD', "繼承");

define('INITIAL_LC_WORD', "初始");

define('INHERIT_LC_WORD', "繼承");

define('RGB_WORD', "#RRGGBB");

define('TEXT_WORD', "文本");

define('ALIGN_WORD', "對齊");

define('BACKGROUND_WORD', "背景");

define('BORDER_WORD', "邊境");

define('SPREAD_WORD', "傳播");

define('INSET_WORD', "插頁");

define('BASELINE_WORD', "底線");

define('SUB_WORD', "子");

define('SUPER_WORD', "超");

define('MIDDLE_WORD', "中間");

define('NONE_WORD', "沒有");

define('RADIUS_WORD', "半徑");

define('MARGIN_WORD', "餘量");

define('AUTO_WORD', "汽車");

define('DISPLAY_WORD', "顯示");

define('VISIBILITY_WORD', "能見度");

define('OVERFLOW_WORD', "溢出");

define('FLOAT_WORD', "浮動");

define('CLIPPING_WORD', "剪裁");

define('IMAGE_WORD', "圖片");

define('ATTACHMENT_WORD', "附件");

define('REPEAT_WORD', "重複");

define('LIST_WORD', "名單");

define('TYPE_WORD', "類型");

define('FIXED_WORD', "固定");

define('SCROLL_WORD', "滾動");

define('SCROLLING_WORD', "滾動");

define('INLINE_WORD', "一致");

define('BLOCK_WORD', "塊");

define('COMPACT_WORD', "緊湊");

define('MARKER_WORD', "標記");

define('TABLE_WORD', "用戶表");

define('XX_SMALL_WORD', "XX小");

define('X_SMALL_WORD', "XX小");

define('SMALL_WORD', "XX小");

define('MEDIUM_WORD', "中");

define('LARGE_WORD', "大");

define('X_LARGE_WORD', "X大");

define('XX_LARGE_WORD', "XX-大");

define('SMALLER_WORD', "小");

define('LARGER_WORD', "較大");

define('NO_WRAP_WORD', "不換行");

define('PRE_WORD', "預");

define('PRE_LINE_WORD', "前行");

define('PRE_WRAP_WORD', "預裹");

define('POINTER_WORD', "指針");

define('CROSSHAIR_WORD', "十字");

define('DEFAULT_WORD', "默認");

define('WAIT_WORD', "等待");

define('HELP_WORD', "幫幫我");

define('ALIAS_WORD', "別號");

define('CELL_WORD', "細胞");

define('COPY_WORD', "複製");

define('RENAME_WORD', "改名");

define('MOVE_WORD', "移動");

define('ASSIGN_WORD', "分配");

define('PROGRESS_WORD', "進展");

define('HIDDEN_WORD', "隱");

define('DOTTED_WORD', "帶點");

define('DASHED_WORD', "虛線");

define('SOLID_WORD', "固體");

define('DOUBLE_WORD', "雙");

define('GROOVE_WORD', "槽");

define('RIDGE_WORD', "嶺");

define('OUTSET_WORD', "開始");

define('COLLAPSE_WORD', "坍方");

define('SEPARATE_WORD', "分離");

define('MIN_WORD', "敏");

define('MAX_WORD', "馬克斯");

define('VISIBLE_WORD', "可見");

define('BOTH_WORD', "都");

define('STATIC_WORD', "靜態的");

define('SCALE_WORD', "規模");

define('COVER_WORD', "蓋");

define('CONTAIN_WORD', "包含");

define('DISC_WORD', "圓盤");

define('CIRCLE_WORD', "圈");

define('SQUARE_WORD', "廣場");

define('DECIMAL_WORD', "十進制");

define('HEBREW_WORD', "希伯來語");

define('ARMENIAN_WORD', "亞美尼亞");

define('GORGIAN_WORD', "格魯吉亞");

define('INSIDE_WORD', "內");

define('OUTSIDE_WORD', "外");

define('CLASS_WORD', "類");

define('SUBCLASS_WORD', "子類");

define('ID_WORD', "用戶名");

define('CUSTOM_WORD', "習俗");

define('_NONE_WORD', "-沒有-");

define('ADD_WORD', "加");

define('OWNER_WORD', "所有者");

define('AUTHOR_WORD', "作者");

define('COPYRIGHT_WORD', "版權");

define('LANGUAGE_WORD', "語言");

define('ABSTRACT_WORD', "抽象");

define('KEYWORDS_WORD', "關鍵詞");

define('SUBJECT_WORD', "學科");

define('ROBOTS_WORD', "機器人");

define('INDEX_WORD', "指數");

define('FOLLOW_WORD', "跟隨");

define('REVISIT_WORD', "重溫");

define('DAYS_WORD', "天");

define('OR_WORD', "錯誤");

define('OR_CAP_WORD', "要么");

define('TO_WORD', "汽車");

define('CLICK_WORD', "點擊");

define('PAGE_WORD', "頁");

define('PAGE_1ST_CAP_WORD', "頁");

define('CONTENT_WORD', "內容");

define('DELETED_WORD', "已刪除");

define('BACKUP_WORD', "備用");

define('RESTORE_WORD', "恢復");

define('REMOVE_WORD', "去掉");

define('CLOSE_WORD', "關");

define('INSTALL_WORD', "安裝");

define('ADMIN_WORD', "聯繫");

define('POWER_USER_WORD', "高級用戶");

define('USER_WORD', "高級用戶");

define('RESTRICTED_WORD', "受限");

define('BLOGGER_WORD', "博主");

define('RECIPIENT_WORD', "接受者");

define('READING_WORD', "讀");

define('PARSING_WORD', "解析");

define('RECALL_WORD', "召回");

define('OPTION_WORD', "選項");

define('VALUE_WORD', "值");

define('MOBILE_WORD', "移動");

define('TRANSPARENT_WORD', "透明");

define('SOURCE_WORD', "資源");

define('CONDENSED_WORD', "簡明");

define('ULTRA_CONDENSED_WORD', "超濃縮");

define('EXTRA_CONDENSED_WORD', "超濃縮");

define('SEMI_WORD', "半濃縮");

define('EXPANDED_WORD', "擴展");

define('SEMI_EXPANDED_WORD', "半擴展");

define('EXTRA_EXPANDED_WORD', "特擴展");

define('ULTRA_EXPANDED_WORD', "超擴展");

define('INDENT_WORD', "縮進");

define('BUILDING_WORD', "建造");

define('STYLE_SHEET_WORD', "樣式表");

define('TITLE_WORD', "標題");

define('REFRESH_WORD', "刷新");

define('FOLDER_WORD', "夾");

define('DOWNLOAD_WORD', "下載");



define('QUERY_READY_TO_SEND', "查詢準備發送...");

define('QUERY_SENT', "發送查詢");

define('QUERY_COMPLETE', "查詢完畢");

define('QUERY_COMPLETE_NO_RECORD_FOUND', "查詢完畢。沒有找到記錄。");

define('SELF_NORMAL', "自我（正常）");

define('NEW_WINDOW', "新窗戶");

define('NAMED_FRAME', "命名框架");

define('ENTER_FRAME_NAME', "輸入框名稱");

define('TEXT_ALIGNMENT', "文本對齊");

define('_NOT_SELECTED_', "哎呀！你忘了選擇一個頁面和/或插件。");

define('_NOT_SET_', "-沒有設置-");

define('_NOT_ASSIGNED_', "-未分配-");

define('LETTER_SPACING', "字母間距");

define('SMALL_CAPS', "小帽子");

define('MOUSE_OUT', "正常（鼠標移出）");

define('MOUSE_OVER', "哈弗（鼠標懸停）");

define('FONT_SIZE', "字體大小");

define('BOX_SHADOW', "箱陰影");

define('BACKGROUND_COLOR', "頂級背景顏色");

define('BORDER_COLOR', "最頂層的方塊邊框顏色");

define('BORDER_STYLE', "邊框樣式");

define('HORIZONTAL_OFFSET', "水平偏移");

define('VERTICAL_OFFSET', "垂直偏移");

define('TEXT_TOP', "文字頂部");

define('TEXT_BOTTOM', "文本底部");

define('VERTICAL_ALIGN', "垂直對齊");

define('LINE_HEIGHT', "行高");

define('SORT_ORDER', "組類排序");

define('LAST_REVISED', "最後修訂日期");

define('GENERATE_PASSWORD', "生成密碼");

define('CHANGE_PASSWORD', "更改密碼");

define('ACCESS_LEVELS', "更改訪問級別...");

define('ADD_USER', "您必須先選擇一個表將用戶添加到。");

define('MODIFY_USER', "修改用戶");

define('DELETE_USER', "你確定要刪除的用戶");

define('NEW_PASSWORD', "新密碼");

define('SELECT_ALL', "全選");

define('CLEAR_ALL', "鎖定清除全部自定義CSS類");

define('TO_TRY_AGAIN', "再試一次。");

define('AND_TRY_AGAIN', "然後再試一次。");

define('NEW_FILE', "新文件");

define('NEW_FOLDER', "新文件夾");

define('FOLDER_NAME', "文件夾名稱");

define('SHOW_BACKUP_FILES', "顯示備份文件");

define('EDIT_MENU_ITEMS_MEGA_MENU', "兆豐菜單");

define('MEGA_MENU_MANAGE_BTN', "管理兆豐菜單");

define('MEGA_MENU_EDIT_SELECT_HEADING', "編輯兆豐菜單");

define('MEGA_MENU_CREATE_HEADING', "創建兆豐菜單");

define('MEGA_MENU_BACK_BTN', "返回編輯菜單項");

define('MEGA_MENU_PAGE_ALREADY_EXISTS_1_ERR', "兆豐菜單");

define('MEGA_MENU_PAGE_ALREADY_EXISTS_2_ERR', "已經存在。請輸入一個不同的名稱或編輯現有的。");

define('MENU_WORD', "菜單");

define('MENU_ITEM', "菜單項");

define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA_BTN', "添加另一個邊境地區");

define('MANAGE_CUSTOM_BORDER_AREA_BACK_BTN', "返回管理邊境地區");

define('MANAGE_HEAD_BACK_BTN', "返回編輯開頭代碼");

define('MANAGE_HEAD_MANAGE_BTN', "管理自定義頭碼");

define('OPTIONS_ENABLE_CSS_MENUS', "啟用CSS菜單");

define('OPTIONS_ENABLE_JS_MENUS', "啟用JavaScript菜單");

define('EDITOR_BACK_TO_SELECT', "返回選擇");

define('COPY_STYLE_TO_MOBILE_BACK_TO_EDIT_CSS_SELECT_BTN', "返回編輯樣式選擇");

define('EDIT_STYLE_SHEET_ATT_BTN', "管理樣式表屬性");

define('MANAGE_STYLE_SHEET_ATT_HEADING', "管理樣式表屬性");

define('MANAGE_STYLE_SHEET_ATT_BACK_TO_EDIT_CSS_SELECT', "返回編輯CSS選擇");

define('MANAGE_STYLE_SHEET_ATT_CHARSET', "字符集");

define('MANAGE_STYLE_SHEET_ATT_IMPORT', "進口");

define('MANAGE_STYLE_SHEET_ATT_MEDIA', "媒體");

define('MANAGE_STYLE_SHEET_ATT_MEDIA_TYPE', "媒體類型");

define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE', "媒體功能");

define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE_VALUE', "媒體功能值");

define('MANAGE_STYLE_SHEET_ATT_ADD_STYLE_SHEET', "添加樣式表");

define('MANAGE_STYLE_SHEET_ATT_DELETE_STYLE_SHEET', "刪除樣式表");

define('MANAGE_STYLE_SHEET_ATT_RENAME_STYLE_SHEET', "重命名樣式表");

define('MANAGE_STYLE_SHEET_ATT_NEW_NAME', "新名稱");

define('MANAGE_STYLE_SHEET_ATT_NEW_DESC', "新的說明");

define('MANAGE_STYLE_SHEET_ATT_SAVE_SUCCESS_MSG', "您的樣式表屬性已被保存。");

define('MANAGE_STYLE_SHEET_ATT_SAVE_ERROR_ERR', "有一個錯誤保存您的樣式表屬性。");

define('MANAGE_STYLE_SHEET_ATT_ADD_SUCCESS_MSG', "您的樣式表已保存。");

define('MANAGE_STYLE_SHEET_ATT_ADD_SHEET_ALREADY_EXISTS_ERR', "該樣式表中已經存在。請選擇一個不同的名稱，然後再試一次");

define('MANAGE_STYLE_SHEET_ATT_ADD_ERROR_ERR', "新增您的樣式表的誤差。");

define('MANAGE_STYLE_SHEET_ATT_DELETE_CONFIRM_MSG', "您確定要刪除");

define('MANAGE_STYLE_SHEET_ATT_DELETE_SUCCESS_MSG', "您的樣式表已被刪除。");

define('MANAGE_STYLE_SHEET_ATT_DELETE_ERROR_ERR', "有一個錯誤刪除您的樣式表。");

define('MANAGE_STYLE_SHEET_ATT_RENAME_SUCCESS_MSG', "您的樣式表已重命名。");

define('MANAGE_STYLE_SHEET_ATT_RENAME_ERROR_ERR', "有一個錯誤重命名樣式表。");

define('NOT_WORD', "不");

define('ONLY_WORD', "只要");

define('ALL_WORD', "所有");

define('PRINT_WORD', "打印");

define('SCREEN_WORD', "屏幕");

define('SPEECH_WORD', "言語");

define('AND_WORD', "和");

define('DESKTOP_WORD', "桌面");

define('MIN_WIDTH', "最小寬度");

define('MAX_WIDTH', "最大寬度");

define('MIN_HEIGHT', "最小高度");

define('MAX_HEIGHT', "最大高度");

define('GET_MORE_PLUGINS_BTN', "獲取更多插件");
define('GET_MORE_TEMPLATES_BTN', "獲取更多模板");
define('MANAGE_STYLE_SHEET_ATT_EXCLUDE_FROM_LIST', "從默認列表中排除");
define('MANAGE_STYLE_SHEET_ATT_SHOW_CUSTOM_STYLES', "顯示自定義樣式");
define('MANAGE_STYLE_SHEET_ATT_SHOW_ALL', "顯示所有的樣式表");
define('UPLOAD_TEMPLATE_UPLOAD_TEMPLATE_COMPLETE', "模板安裝完成。");
define('CREATE_PAGE_SELECT_CREATE_PLUGIN_GROUP', "創建這個插件組的所有插件頁面");
define('CREATE_PAGE_SELECT_ALREADY_EXISTS_ERR', "未定義");
define('MANAGE_STYLE_SHEET_SET_SORT_ORDER', "設置樣式表排序");
define('MANAGE_STYLE_SHEET_NAME_DESCRIPTION', "樣式表/說明");
define('EDIT_CSS_SHOW_ALL_CLASSES', "顯示所有類別");
define('EDIT_CSS_MENU_STYLES_OMIT_ADJACENT_BORDERS', "O&lt;br&gt;m&lt;br&gt;i&lt;br&gt;t&lt;br&gt;&lt;br&gt;A&lt;br&gt;d&lt;br&gt;j&lt;br&gt;a&lt;br&gt;c&lt;br&gt;e&lt;br&gt;n&lt;br&gt;t&lt;br&gt;&lt;br&gt;B&lt;br&gt;o&lt;br&gt;r&lt;br&gt;d&lt;br&gt;e&lt;br&gt;r&lt;br&gt;s");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_1_SIZE_PADDING', "子菜單1項目大小和填充");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_2_SIZE_PADDING', "子菜單2項目大小和填充");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SPACING', "項目間距");
define('EDIT_CSS_MENU_STYLES_DOWN', "向下（向下按鈕）");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BACKGROUND_COLOR', "子水位1背景顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BACKGROUND_COLOR', "Sub Level 2 Background Color");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_ITEM_BORDER_COLOR', "子水位1項邊框顏色");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_ITEM_BORDER_COLOR', "子水位2項邊框顏色");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_1', "CSS菜單參數尚未設置。請點擊");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_2', "設置的CSS菜單參數");
define('BORDER_RADIUS', "圓角半徑");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1', "子水位1");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2', "分2級");
define('EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG', "您有尚未保存的新項目。請添加一個新的之前保存該項目。");
define('EDIT_CSS_MENU_STYLES_SHADOW_COLOR', "陰影顏色");
define('EDIT_CSS_MENU_STYLES_HOVER_ON_DOWN', "將鼠標懸停下來");
define('EDIT_CSS_FOREGROUND_OPAQUE_1', "前景");
define('EDIT_CSS_FOREGROUND_OPAQUE_2', "不透明");
define('ADMIN_FUNCTION_SELECT_RESTRICT_BLOG_PAGE_EDITING_ACCESS_BTN', "限制博客頁面編輯訪問");
define('RESTRICT_BLOG_EDITING_HEADING', "限制對博客訪問博客");
define('USERS_WORD', "用戶");
define('PUBLISHED_WORD', "發布時間");
define('DRAFT_WORD', "草案");
define('ADD_ALL', "全部添加");
define('BLOG_PAGE', "博客頁面");
define('EDIT_CSS_FLEX', "柔性");
define('EDIT_CSS_INLINE_FLEX', "內嵌-FLEX");
define('EDIT_CSS_CONTENT_TEXT', "內容文本");
define('EDIT_CSS_JUSTIFY_CONTENT', "證明內容");
define('EDIT_CSS_SET_CONTENT_BLANK', "設置內容空白");
define('EDIT_CSS_FLEX_START', "Flex開始");
define('EDIT_CSS_FLEX_END', "Flex End");
define('EDIT_CSS_SPACE_BETWEEN', "之間的空間");
define('EDIT_CSS_SPACE_AROUND', "周圍空間");
define('EDIT_CSS_SET_DISPLAY_FLEX', "設置顯示Flex");
define('EDIT_CSS_WRAP_REVERSE', "回捲");
define('EDIT_CSS_ROW_REVERSE', "行反向");
define('EDIT_CSS_COLUMN_REVERSE', "Column Reverse");
define('EDIT_CSS_DISPLAY_SET_TO_FLEX', "顯示屬性已設置為“flex”。");
define('EDIT_CSS_CONTENT_SET_TO_BLANK', "字符串&#39;-blank-&#39;告訴CSS字符串編譯器將內容設置為&#39;&#39;。");
define('WRAP_WORD', "包");
define('CAPITALIZE_WORD', "大寫");
define('UPPERCASE_WORD', "大寫");
define('LOWERCASE_WORD', "小寫");
define('STRING_WORD', "串");
define('ATTRIBUTE_WORD', "屬性");
define('COUNTER_WORD', "計數器");
define('TRANSITION_WORD', "過渡");
define('PROPERTY_WORD', "屬性");
define('DURATION_WORD', "Duration");
define('DELAY_WORD', "延遲");
define('EASE_WORD', "緩解");
define('LINEAR_WORD', "線性");
define('BASIS_WORD', "基礎");
define('GROW_WORD', "增長");
define('SHRINK_WORD', "收縮");
define('LENGTH_WORD', "長度");
define('DIRECTION_WORD', "方向");
define('ROW_WORD', "行");
define('COLUMN_WORD', "柱");
define('TEXT_TRANSFORM', "文本變換");
define('OPEN_QUOTE', "打開報價");
define('CLOSE_QUOTE', "關閉報價");
define('NO_OPEN_QUOTE', "沒打開報價");
define('NO_CLOSE_QUOTE', "沒有關閉報價");
define('TIMING_FUNCTION', "定時功能");
define('EASE_IN', "容易入");
define('EASE_OUT', "緩解");
define('EASE_IN_OUT', "輕鬆進出");
define('WIDTH_AND_HEIGHT', "寬度和高度");
define('EDIT_CSS_ENTER_STR_MSG', "在“內容文本輸入”字段中輸入要用作內容的文本，或將空白設置為空白。");
define('EDIT_CSS_ENTER_URL_MSG', "在內容文本輸入字段中輸入URL。");
define('EDIT_CSS_ENTER_ATTR_MSG', "在內容文本輸入字段中輸入HTML對象attribite，即&#39;href&#39;或&#39;name&#39;。");
define('IMPORTANT_HEADING', "管理重要的CSS屬性");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR', "表缺少用戶登錄字段。如果要使用此表進行用戶訪問，必須先使用“將用戶登錄字段添加到表”按鈕添加到此表的用戶登錄字段。");
define('THRU_WORD', "通");
define('OF_WORD', "的");
define('SHOWING_RECORDS', "顯示記錄");
define('FIRST_NAME', "名字");
define('LAST_NAME', "姓");
define('EDIT_CSS_MENU_PARAMETERS_LATCH_EXPANDED_ON_DOWN', "鎖定擴展子項目");
define('RADIAL_WORD', "徑向");
define('ANGLE_WORD', "角度");
define('DEGREES_WORD', "學位");
define('BACKGROUND_GRADIENT', "背景漸變");
define('TOP_TO_BOTTOM', "從上到下");
define('BOTTOM_LEFT_TO_TOP_RIGHT', "左下到右上");
define('LEFT_TO_RIGHT', "Left to Right");
define('TOP_LEFT_TO_BOTTOM_RIGHT', "左上到右下");
define('BOTTOM_TO_TOP', "從底部到頂部");
define('TOP_RIGHT_TO_BOTTOM_LEFT', "右上到左下");
define('RIGHT_TO_LEFT', "右到左");
define('BOTTOM_RIGHT_TO_TOP_LEFT', "左上右下");
define('EDIT_CSS_MENU_PARAMETERS_SUB_1_MENU_POSITIONING', "子菜單1佈局和定位");
define('EDIT_CSS_MENU_PARAMETERS_SUB_2_MENU_POSITIONING', "子菜單2佈局和定位");
define('HOVER_WORD', "徘徊");
define('DOWN_WORD', "下");
define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "基數指數");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "該類別下沒有插件");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "點擊");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "在該類別中找到一個插件。");
define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "管理我的帳戶");
define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "您的密碼已更新為臨時密碼。建議您將密碼更改為更易於輸入和記憶的密碼，然後將新密碼存儲在安全的位置。你想現在改變你的密碼嗎？");
define('MANAGE_USERS_CHANGE_MY_PASSWORD', "修改我的密碼");
define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "修改我的帳戶");
define('STICKY_WORD', "黏");
define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "粘滯標題的設置");
define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "現在，我們將使用設置加載樣式，這些設置會導致網頁標題“粘”到瀏覽器窗口的頂部。");
define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "您的標題現在將粘貼到瀏覽器窗口的頂部。");
define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "複製字體...");
define('MANAGE_MENUS_COPY_MENU_BTN', "複製菜單");
define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "複製菜單項目");
define('MANAGE_MENUS_CREATE_NEW', "新菜單");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "你確定你想複製這個");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "菜單");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "菜單？");
define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "菜單項");
define('TO_1ST_CAP_WORD', "至");
define('FROM_WORD', "從");
define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_HEADING', "將菜單項複製到桌面，手機或觸摸屏菜單");
define('MANAGE_MENUS_DESTINATION_TYPE', "目標類型");
define('TOUCHSCREEN_WORD', "觸摸屏");
define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "您的樣式表已被複製。");
define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "複製樣式表時出錯。");
define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "來源類型");
define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "目的地類型未被選中。請選擇目的地類型，然後重試。");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "子級別2塊邊框顏色");
define('MANAGE_FONTS_INSTRUCTIONS_1', "注意：除非您點擊，否則更改不會被記錄");
define('MANAGE_FONTS_INSTRUCTIONS_2', "點擊");
define('MANAGE_FONTS_INSTRUCTIONS_3', "將使用新參數創建您的字體的副本。如果您只是更改字體參數，請單擊");
define('MANAGE_FONTS_INSTRUCTIONS_4', "在原始字體旁邊刪除它。只允許TTF，OTF，WOFF，WOFF2，SVG和EOT的文件類型。");
define('MANAGE_FONTS_FONT_SAVED_MSG', "字體已保存。");
define('MANAGE_FONTS_ERROR_SAVING_FONT_ERR', "保存字體時出錯。");
define('MANAGE_FONTS_ADD_BEFORE_SAVE_NEW_MSG', "您有一個尚未保存的新字體。請在添加新字體之前保存該字體。");
define('MANAGE_FONTS_FONT_UPLOADED_MSG', "您的字體文件已上傳。");
define('MANAGE_FONTS_FONT_UPLOAD_ERR', "試圖上傳字體時出錯。");
define('MANAGE_FONTS_FONT_UPLOAD_CANCEL_MSG', "上傳已被用戶取消或瀏覽器斷開連接。");
define('MANAGE_FONTS_NO_FONT_ERR', "&#39;字體&#39;不能為空。");
define('MANAGE_FONTS_NO_UPLOAD_ERR', "如果選擇“上傳”，則必須從您的計算機中選擇要上傳的文件。");
define('MANAGE_FONTS_NO_URL_ERR', "如果選中“網址”，則“網址”不能為空。");
define('RUN_SQL_BACK_TO_EDIT_CSS_SELECT', "返回運行SQL");
define('RUN_SQL_QUERY_SUCCESS_MSG', "查詢成功完成");
?>